@@ -22,185 +22,184 @@
     without including the source code for Qt in the source distribution.
 */
 
-#include <qregexp.h>
-#include <qstylesheet.h>
+#include "frame.h"
+
+#include <QGridLayout>
+#include <QRegExp>
 
 #include <kactioncollection.h>
 #include <kdebug.h>
 #include <klocale.h>
+#include <kurl.h>
 #include <kparts/browserextension.h>
 #include <kparts/part.h>
 
 #include <libkdepim/progressmanager.h>
 
-#include "frame.h"
-
 namespace Akregator {
 
-Frame::Frame(QObject * parent, KParts::ReadOnlyPart *p, QWidget *visWidget, const QString& tit, bool watchSignals)
-   :QObject(parent, "aKregatorFrame")
-{
-    m_autoDeletePart = false;
-    m_part=p;
-    m_widget=visWidget;
-    m_title=tit;
-    m_state=Idle;
-    m_progress=-1;
-    m_progressItem=0;
 
-    if (watchSignals) // e.g, articles tab has no part
-    {
-        connect(m_part, SIGNAL(setWindowCaption (const QString &)), this, SLOT(setCaption (const QString &)));
-        connect(m_part, SIGNAL(setStatusBarText (const QString &)), this, SLOT(setStatusText (const QString &)));
-
-        KParts::BrowserExtension *ext=KParts::BrowserExtension::childObject( p );
-        if (ext)
-            connect( ext, SIGNAL(loadingProgress(int)), this, SLOT(setProgress(int)) );
-
-        connect(p, SIGNAL(started(KIO::Job*)), this, SLOT(setStarted()));
-        connect(p, SIGNAL(completed()), this, SLOT(setCompleted()));
-        connect(p, SIGNAL(canceled(const QString &)), this, SLOT(setCanceled(const QString&)));
-        connect(p, SIGNAL(completed(bool)), this, SLOT(setCompleted()));
-
-/*        KActionCollection *coll=p->actionCollection();
-        if (coll)
-        {
-            connect( coll, SIGNAL( actionStatusText( const QString & ) ),
-             this, SLOT( slotActionStatusText( const QString & ) ) );
-            connect( coll, SIGNAL( clearStatusText() ),
-             this, SLOT( slotClearStatusText() ) );
-        }
-*/
-    }
-}
-
-void Frame::setAutoDeletePart(bool autoDelete)
-{
-    m_autoDeletePart = autoDelete;
-}
-
-Frame::~Frame()
-{
-    if(m_progressItem) 
-    {
-        m_progressItem->setComplete();
-    }
-    if (m_autoDeletePart)
-        m_part->deleteLater();
-}
-
-int Frame::state() const
-{
-    return m_state;
-}
-
-KParts::ReadOnlyPart *Frame::part() const
-{
-    return m_part;
-}
-
-QWidget *Frame::widget() const
-{
-    return m_widget;
-}
-
-void Frame::setTitle(const QString &s)
+void Frame::slotSetTitle(const QString &s)
 {
     if (m_title != s)
     {
         m_title = s;
-        emit titleChanged(this, s);
+        emit signalTitleChanged(this, s);
     }
 }
 
-void Frame::setCaption(const QString &s)
+bool Frame::isLoading() const 
+{
+    return m_loading;
+}
+
+void Frame::slotSetCaption(const QString &s)
 {
     if(m_progressItem) m_progressItem->setLabel(s);
     m_caption=s;
-    emit captionChanged(s);
+    emit signalCaptionChanged(this, s);
 }
 
-void Frame::setStatusText(const QString &s)
+void Frame::slotSetStatusText(const QString &s)
 {
     m_statusText=s;
-    m_statusText.replace(QRegExp("<[^>]*>"), "");
-    emit statusText(m_statusText);
+    m_statusText.remove(QRegExp("<[^>]*>"));
+    emit signalStatusText(this, m_statusText);
 }
 
-void Frame::setProgress(int a)
+void Frame::slotSetProgress(int a)
 {
     if(m_progressItem) {
         m_progressItem->setProgress((int)a);
     }
     m_progress=a;
-    emit loadingProgress(a);
+    emit signalLoadingProgress(this, a);
 }
 
-void Frame::setState(int a)
+void Frame::slotSetState(State state)
 {
-    m_state=a;
-    
+    m_state=state;
+
     switch (m_state)
     {
         case Frame::Started:
-            emit started();
+            emit signalStarted(this);
             break;
         case Frame::Canceled:
-            emit canceled(QString::null);
+            emit signalCanceled(this, QString());
             break;
         case Frame::Idle:
         case Frame::Completed:
         default:
-            emit completed();
-    }}
+            emit signalCompleted(this);
+    }
+}
+
+Frame::Frame(QWidget* parent)
+   : QWidget(parent)
+{
+    m_title = i18n("Untitled");
+    m_state=Idle;
+    m_progress=-1;
+    m_progressItem=0;
+    m_isRemovable = true;
+    m_loading = false; 
+    m_id = m_idCounter++;
+}
+
+int Frame::m_idCounter = 0;
+
+int Frame::id() const
+{
+    return m_id;
+}
+
+void Frame::setRemovable(bool removable)
+{
+    m_isRemovable = removable;
+}
+
+bool Frame::isRemovable() const
+{
+    return m_isRemovable;
+}
+
+Frame::~Frame()
+{
+    if(m_progressItem)
+    {
+        m_progressItem->setComplete();
+    }
+}
 
 
+Frame::State Frame::state() const
+{
+    return m_state;
+}
 
-const QString& Frame::title() const
+QString Frame::title() const
 {
     return m_title;
 }
 
-const QString& Frame::caption() const
+QString Frame::caption() const
 {
     return m_caption;
 }
 
-const QString& Frame::statusText() const
+QString Frame::statusText() const
 {
     return m_statusText;
 }
 
-void Frame::setStarted()
+void Frame::slotSetStarted()
 {
+    m_loading = true;
     if(m_progressId.isNull() || m_progressId.isEmpty()) m_progressId = KPIM::ProgressManager::getUniqueID();
-    m_progressItem = KPIM::ProgressManager::createProgressItem(m_progressId, QStyleSheet::escape( title() ), QString::null, false);
+    m_progressItem = KPIM::ProgressManager::createProgressItem(m_progressId, title(), QString(), false);
     m_progressItem->setStatus(i18n("Loading..."));
     //connect(m_progressItem, SIGNAL(progressItemCanceled(KPIM::ProgressItem*)), SLOT(slotAbortFetch()));
     m_state=Started;
-    emit started();
+    emit signalStarted(this);
+    emit signalIsLoadingToggled(this, m_loading);
 }
 
-void Frame::setCanceled(const QString &s)
+void Frame::slotStop()
 {
-    if(m_progressItem) {
+    if (m_loading)
+    {
+        m_loading = false;
+        emit signalIsLoadingToggled(this, false);
+    }
+}
+
+void Frame::slotSetCanceled(const QString &s)
+{
+    m_loading = false;
+    if(m_progressItem) 
+    {
         m_progressItem->setStatus(i18n("Loading canceled"));
         m_progressItem->setComplete();
         m_progressItem = 0;
     }
     m_state=Canceled;
-    emit canceled(s);
+    emit signalCanceled(this, s);
+    emit signalIsLoadingToggled(this, m_loading);
 }
 
-void Frame::setCompleted()
+void Frame::slotSetCompleted()
 {
-    if(m_progressItem) {
+    m_loading = false; 
+    if(m_progressItem)
+    {
         m_progressItem->setStatus(i18n("Loading completed"));
         m_progressItem->setComplete();
         m_progressItem = 0;
     }
     m_state=Completed;
-    emit completed();
+    emit signalCompleted(this);
+    emit signalIsLoadingToggled(this, m_loading);
 }
 
 int Frame::progress() const
@@ -208,6 +207,24 @@ int Frame::progress() const
     return m_progress;
 }
 
+MainFrame::MainFrame(QWidget* parent, KParts::ReadOnlyPart* part, QWidget* visibleWidget) : Frame(parent), m_part(part)
+{
+    setRemovable(false);
+    QGridLayout* layout = new QGridLayout(this);
+    layout->setMargin(0);
+    layout->addWidget(visibleWidget, 0, 0);
+    setLayout(layout);
+}
+
+MainFrame::~MainFrame()
+{
+}
+
+KUrl MainFrame::url() const
+{
+    return KUrl();
+}
+
 } // namespace Akregator
 
 #include "frame.moc"
