@@ -23,8 +23,8 @@
 
 #include <QObject>
 #include <kurl.h>
-#include "alarmevent.h"
 #include "alarmresources.h"
+#include "kaevent.h"
 
 namespace KCal {
   class Calendar;
@@ -56,6 +56,8 @@ class AlarmCalendar : public QObject
 		bool                  endUpdate();
 		KAEvent*              earliestAlarm() const;
 		void                  setAlarmPending(KAEvent*, bool pending = true);
+		bool                  haveDisabledAlarms() const   { return mHaveDisabledAlarms; }
+		void                  disabledChanged(const KAEvent*);
 		KAEvent::List         atLoginAlarms() const;
 		KCal::Event*          createKCalEvent(const KAEvent* e, bool original = false) const
 		                                             { return createKCalEvent(e, QString(), original); }
@@ -81,7 +83,6 @@ class AlarmCalendar : public QObject
 		QString               urlString() const      { return (mCalType == RESOURCES) ? QString() : mUrl.url(); }
 		void                  adjustStartOfDay();
 
-		static QString        icalProductId();
 		static bool           initialiseCalendars();
 		static void           terminateCalendars();
 		static AlarmCalendar* resources()            { return mResourcesCalendar; }
@@ -94,6 +95,7 @@ class AlarmCalendar : public QObject
 
 	signals:
 		void                  earliestAlarmChanged();
+		void                  haveDisabledAlarmsChanged(bool haveDisabled);
 		void                  calendarSaved(AlarmCalendar*);
 
 	private slots:
@@ -119,6 +121,8 @@ class AlarmCalendar : public QObject
 		static void           updateResourceKAEvents(AlarmResource*, KCal::CalendarLocal*);
 		void                  removeKAEvents(AlarmResource*, bool closing = false);
 		void                  findEarliestAlarm(AlarmResource*);
+		void                  checkForDisabledAlarms();
+		void                  checkForDisabledAlarms(bool oldEnabled, bool newEnabled);
 
 		static AlarmCalendar* mResourcesCalendar;  // the calendar resources
 		static AlarmCalendar* mDisplayCalendar;    // the display calendar
@@ -140,6 +144,7 @@ class AlarmCalendar : public QObject
 		bool                  mOpen;               // true if the calendar file is open
 		int                   mUpdateCount;        // nesting level of group of calendar update calls
 		bool                  mUpdateSave;         // save() was called while mUpdateCount > 0
+		bool                  mHaveDisabledAlarms; // there is at least one individually disabled alarm
 
 		using QObject::event;   // prevent "hidden" warning
 };
