@@ -1,7 +1,7 @@
 /*
  *  find.cpp  -  search facility
  *  Program:  kalarm
- *  Copyright © 2005-2008 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2005-2009 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,10 +33,10 @@
 #include <kmessagebox.h>
 #include <kdebug.h>
 
-#include "alarmevent.h"
 #include "alarmlistfiltermodel.h"
 #include "alarmlistview.h"
 #include "eventlistview.h"
+#include "kaevent.h"
 #include "preferences.h"
 #include "find.moc"
 
@@ -47,9 +47,10 @@ enum {
 	FIND_MESSAGE  = KFind::MinimumUserOption << 2,
 	FIND_FILE     = KFind::MinimumUserOption << 3,
 	FIND_COMMAND  = KFind::MinimumUserOption << 4,
-	FIND_EMAIL    = KFind::MinimumUserOption << 5
+	FIND_EMAIL    = KFind::MinimumUserOption << 5,
+	FIND_AUDIO    = KFind::MinimumUserOption << 6
 };
-static long FIND_KALARM_OPTIONS = FIND_LIVE | FIND_ARCHIVED | FIND_MESSAGE | FIND_FILE | FIND_COMMAND | FIND_EMAIL;
+static long FIND_KALARM_OPTIONS = FIND_LIVE | FIND_ARCHIVED | FIND_MESSAGE | FIND_FILE | FIND_COMMAND | FIND_EMAIL | FIND_AUDIO;
 
 
 class FindDlg : public KFindDialog
@@ -98,7 +99,7 @@ void Find::display()
 {
 	if (!mOptions)
 		// Set defaults the first time the Find dialog is activated
-		mOptions = FIND_LIVE | FIND_ARCHIVED | FIND_MESSAGE | FIND_FILE | FIND_COMMAND | FIND_EMAIL;
+		mOptions = FIND_LIVE | FIND_ARCHIVED | FIND_MESSAGE | FIND_FILE | FIND_COMMAND | FIND_EMAIL | FIND_AUDIO;
 	bool noArchived = !Preferences::archivedKeepDays();
 	bool showArchived = qobject_cast<AlarmListView*>(mListView)
 	                    && (static_cast<AlarmListFilterModel*>(mListView->model())->statusFilter() & KCalEvent::ARCHIVED);
@@ -166,6 +167,11 @@ void Find::display()
 		mEmailType->setWhatsThis(i18nc("@info:whatsthis", "Check to include email alarms in the search."));
 		grid->addWidget(mEmailType, 4, 2);
 
+		mAudioType = new QCheckBox(i18nc("@option:check Alarm action", "Audio"), group);
+		mAudioType->setFixedSize(mAudioType->sizeHint());
+		mAudioType->setWhatsThis(i18nc("@info:whatsthis", "Check to include audio alarms in the search."));
+		grid->addWidget(mAudioType, 5, 0);
+
 		// Set defaults
 		mLive->setChecked(mOptions & FIND_LIVE);
 		mArchived->setChecked(mOptions & FIND_ARCHIVED);
@@ -173,6 +179,7 @@ void Find::display()
 		mFileType->setChecked(mOptions & FIND_FILE);
 		mCommandType->setChecked(mOptions & FIND_COMMAND);
 		mEmailType->setChecked(mOptions & FIND_EMAIL);
+		mAudioType->setChecked(mOptions & FIND_AUDIO);
 
 		connect(mDialog, SIGNAL(okClicked()), this, SLOT(slotFind()));
 	}
@@ -198,6 +205,7 @@ void Find::display()
 	bool file     = false;
 	bool command  = false;
 	bool email    = false;
+	bool audio    = false;
 	int rowCount = mListView->model()->rowCount();
 	for (int row = 0;  row < rowCount;  ++row)
 	{
@@ -208,10 +216,11 @@ void Find::display()
 			live = true;
 		switch (event->action())
 		{
-			case KAEvent::MESSAGE:  text    = true;  break;
-			case KAEvent::FILE:     file    = true;  break;
-			case KAEvent::COMMAND:  command = true;  break;
-			case KAEvent::EMAIL:    email   = true;  break;
+			case KAEventData::MESSAGE:  text    = true;  break;
+			case KAEventData::FILE:     file    = true;  break;
+			case KAEventData::COMMAND:  command = true;  break;
+			case KAEventData::EMAIL:    email   = true;  break;
+			case KAEventData::AUDIO:    audio   = true;  break;
 		}
 	}
 	mLive->setEnabled(live);
@@ -220,6 +229,7 @@ void Find::display()
 	mFileType->setEnabled(file);
 	mCommandType->setEnabled(command);
 	mEmailType->setEnabled(email);
+	mAudioType->setEnabled(audio);
 
 	mDialog->setHasCursor(mListView->selectionModel()->currentIndex().isValid());
 	mDialog->show();
@@ -239,9 +249,10 @@ void Find::slotFind()
 	         |  (mMessageType->isEnabled() && mMessageType->isChecked() ? FIND_MESSAGE : 0)
 	         |  (mFileType->isEnabled()    && mFileType->isChecked()    ? FIND_FILE : 0)
 	         |  (mCommandType->isEnabled() && mCommandType->isChecked() ? FIND_COMMAND : 0)
-	         |  (mEmailType->isEnabled()   && mEmailType->isChecked()   ? FIND_EMAIL : 0);
+	         |  (mEmailType->isEnabled()   && mEmailType->isChecked()   ? FIND_EMAIL : 0)
+	         |  (mAudioType->isEnabled()   && mAudioType->isChecked()   ? FIND_AUDIO : 0);
 	if (!(mOptions & (FIND_LIVE | FIND_ARCHIVED))
-	||  !(mOptions & (FIND_MESSAGE | FIND_FILE | FIND_COMMAND | FIND_EMAIL)))
+	||  !(mOptions & (FIND_MESSAGE | FIND_FILE | FIND_COMMAND | FIND_EMAIL | FIND_AUDIO)))
 	{
 		KMessageBox::sorry(mDialog, i18nc("@info", "No alarm types are selected to search"));
 		return;
@@ -318,28 +329,28 @@ void Find::findNext(bool forward, bool checkEnd, bool fromCurrent)
 			continue;     // we're not searching this type of alarm
 		switch (event->action())
 		{
-			case KAEvent::MESSAGE:
+			case KAEventData::MESSAGE:
 				if (!(mOptions & FIND_MESSAGE))
 					break;
 				mFind->setData(event->cleanText());
 				found = (mFind->find() == KFind::Match);
 				break;
 
-			case KAEvent::FILE:
+			case KAEventData::FILE:
 				if (!(mOptions & FIND_FILE))
 					break;
 				mFind->setData(event->cleanText());
 				found = (mFind->find() == KFind::Match);
 				break;
 
-			case KAEvent::COMMAND:
+			case KAEventData::COMMAND:
 				if (!(mOptions & FIND_COMMAND))
 					break;
 				mFind->setData(event->cleanText());
 				found = (mFind->find() == KFind::Match);
 				break;
 
-			case KAEvent::EMAIL:
+			case KAEventData::EMAIL:
 				if (!(mOptions & FIND_EMAIL))
 					break;
 				mFind->setData(event->emailAddresses(", "));
@@ -357,6 +368,13 @@ void Find::findNext(bool forward, bool checkEnd, bool fromCurrent)
 				mFind->setData(event->cleanText());
 				found = (mFind->find() == KFind::Match);
 				break;
+
+			case KAEventData::AUDIO:
+				if (!(mOptions & FIND_AUDIO))
+					break;
+				mFind->setData(event->audioFile());
+				found = (mFind->find() == KFind::Match);
+				break;
 		}
 		if (found)
 			break;
