@@ -254,6 +254,27 @@ void KAlarmPrefDlg::slotCancel()
 	KDialog::reject();
 }
 
+// Reset all controls to the application defaults
+void KAlarmPrefDlg::slotDefault()
+{
+	switch (KMessageBox::questionYesNoCancel(this, i18nc("@info", "Reset all tabs to their default values, or only reset the current tab?"),
+	                                         QString(),
+	                                         KGuiItem(i18nc("@action:button Reset ALL tabs", "&All")),
+						 KGuiItem(i18nc("@action:button Reset the CURRENT tab", "C&urrent"))))
+	{
+		case KMessageBox::Yes:
+			restore(true);   // restore all tabs
+			break;
+		case KMessageBox::No:
+			Preferences::self()->useDefaults(true);
+			static_cast<PrefsTabBase*>(currentPage()->widget())->restore(true);
+			Preferences::self()->useDefaults(false);
+			break;
+		default:
+			break;
+	}
+}
+
 // Discard the current preferences and use the present ones
 void KAlarmPrefDlg::restore(bool defaults)
 {
@@ -482,7 +503,6 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
 
 void MiscPrefTab::restore(bool defaults)
 {
-	Q_UNUSED(defaults);
 	mAutoStart->setChecked(defaults ? true : Preferences::autoStart());
 	mQuitWarn->setChecked(Preferences::quitWarn());
 	mConfirmAlarmDeletion->setChecked(Preferences::confirmAlarmDeletion());
@@ -702,6 +722,29 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
 	itemBox->leftAlign();
 	box->setFixedHeight(box->sizeHint().height());
 
+	// KOrganizer event duration
+	group = new QGroupBox(i18nc("@title:group", "KOrganizer"), topWidget());
+	layout = new QVBoxLayout(group);
+	layout->setMargin(KDialog::marginHint());
+	layout->setSpacing(KDialog::spacingHint());
+
+	itemBox = new ItemBox(group);
+	itemBox->setMargin(0);
+	layout->addWidget(itemBox);
+	box = new KHBox(itemBox);   // this is to control the QWhatsThis text display area
+	box->setMargin(0);
+	box->setSpacing(KDialog::spacingHint());
+	label = new QLabel(i18nc("@label:spinbox", "KOrganizer event duration:"), box);
+	addAlignedLabel(label);
+	mKOrgEventDuration = new TimeSpinBox(0, 5999, box);
+	mKOrgEventDuration->setMinimumSize(mKOrgEventDuration->sizeHint());
+	box->setWhatsThis(i18nc("@info:whatsthis",
+	      "<para>Enter the event duration in hours and minutes, for alarms which are copied to KOrganizer.</para>"
+	      "<para>%1</para>", TimeSpinBox::shiftWhatsThis()));
+	label->setBuddy(mKOrgEventDuration);
+	itemBox->setStretchFactor(new QWidget(itemBox), 1);    // left adjust the controls
+	itemBox->setFixedHeight(itemBox->sizeHint().height());
+
 	topLayout()->addStretch();    // top adjust the widgets
 }
 
@@ -748,6 +791,7 @@ void TimePrefTab::restore(bool)
 		bool x = days.testBit(KAlarm::localeDayInWeek_to_weekDay(i) - 1);
 		mWorkDays[i]->setChecked(x);
 	}
+	mKOrgEventDuration->setValue(Preferences::kOrgEventDuration());
 }
 
 void TimePrefTab::apply(bool syncToDisc)
@@ -777,6 +821,10 @@ void TimePrefTab::apply(bool syncToDisc)
 		if (mWorkDays[i]->isChecked())
 			workDays.setBit(KAlarm::localeDayInWeek_to_weekDay(i) - 1, 1);
 	Preferences::setWorkDays(workDays);
+	Preferences::setKOrgEventDuration(mKOrgEventDuration->value());
+	t = mKOrgEventDuration->value();
+	if (t != Preferences::kOrgEventDuration())
+		Preferences::setKOrgEventDuration(t);
 	PrefsTabBase::apply(syncToDisc);
 }
 
@@ -1280,7 +1328,7 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
 	mSoundRepeat = new QCheckBox(i18nc("@option:check", "Repeat sound file"), bbox);
 	mSoundRepeat->setMinimumSize(mSoundRepeat->sizeHint());
 	mSoundRepeat->setWhatsThis(
-	      i18nc("@info:whatsthis sound file 'Repeat' checkbox", "The default setting for sound file <interface>%1</interface> in the alarm edit dialog.", SoundDlg::i18n_chk_Repeat()));
+	      i18nc("@info:whatsthis sound file 'Repeat' checkbox", "The default setting for sound file <interface>%1</interface> in the alarm edit dialog.", SoundWidget::i18n_chk_Repeat()));
 	hlayout->addWidget(mSoundRepeat);
 
 	box = new KHBox(bbox);   // this is to control the QWhatsThis text display area
