@@ -46,6 +46,7 @@
 #ifdef HAVE_KLEOPATRACLIENT_LIBRARY
 # include <selftest/uiservercheck.h>
 #endif
+#include <selftest/gpgagentcheck.h>
 
 #include <utils/stl_util.h>
 
@@ -142,6 +143,9 @@ private:
         //emit q->info( i18n("Checking Ui Server connectivity...") );
         tests.push_back( makeUiServerConnectivitySelfTest() );
 #endif
+#ifndef Q_OS_WIN
+        tests.push_back( makeGpgAgentConnectivitySelfTest() );
+#endif
 
         if ( !dialog && kdtools::none_of( tests, mem_fn( &Kleo::SelfTest::failed ) ) ) {
             finished();
