@@ -42,7 +42,7 @@
 #include "libkleo/kleo/cryptobackendfactory.h"
 #include "libkleo/kleo/keyfiltermanager.h"
 
-#ifdef ONLY_KLEO
+#ifdef KDEPIM_ONLY_KLEO
 # include <utils/kleo_kicondialog.h>
 #else
 # include <kicondialog.h>
@@ -70,7 +70,7 @@
 using namespace Kleo;
 using namespace Kleo::Config;
 using namespace boost;
-#ifdef ONLY_KLEO
+#ifdef KDEPIM_ONLY_KLEO
 using namespace Kleo::KioAvoidance;
 #endif
 
@@ -183,13 +183,13 @@ static void erase_if_allowed( QListWidgetItem * item, int role, int allowRole )
         item->setData( role, QVariant() );
 }
 
+#if 0
 static void erase_if_allowed( QListWidgetItem * item, const int role[], size_t numRoles, int allowRole ) {
     if ( item && item->data( allowRole ).toBool() )
         for ( unsigned int i = 0 ; i < numRoles ; ++i )
             item->setData( role[i], QVariant() );
 }
 
-#if 0
 static void erase_if_allowed( QListWidgetItem * item, int role, const int allowRole[], size_t numAllowRoles ) {
     if ( !item )
         return;
@@ -215,8 +215,7 @@ static void set_default_appearance( QListWidgetItem * item ) {
         return;
     erase_if_allowed( item, Qt::ForegroundRole, MayChangeForegroundRole );
     erase_if_allowed( item, Qt::BackgroundRole, MayChangeBackgroundRole );
-    static const int iconRoles[] = { Qt::DecorationRole, MayChangeIconRole };
-    erase_if_allowed( item, iconRoles, size( iconRoles ), MayChangeIconRole );
+    erase_if_allowed( item, Qt::DecorationRole, MayChangeIconRole );
     static const int fontRoles[] = { Qt::FontRole, HasFontRole };
     static const int fontAllowRoles[] = {
         MayChangeFontRole,
@@ -235,11 +234,12 @@ static void writeOrDelete( KConfigGroup & group, const char * key, const QVarian
 }
 
 static QVariant brush2color( const QVariant & v ) {
-    if ( v.isValid() )
+    if ( v.isValid() ) {
         if ( v.type() == QVariant::Color )
             return v;
         else if ( v.type() == QVariant::Brush )
             return v.value<QBrush>().color();
+    }
     return QVariant();
 }
 
@@ -452,6 +452,7 @@ void AppearanceConfigWidget::Private::slotIconClicked() {
 
     item->setIcon( KIcon( iconName ) );
     item->setData( IconNameRole, iconName );
+    emit q->changed();
 }
 
 void AppearanceConfigWidget::Private::slotForegroundClicked() {
