@@ -37,16 +37,9 @@
 #include <QList>
 
 class QRegExpValidator;
-class QCheckBox;
-class QPushButton;
-class QLabel;
-class QRadioButton;
-class QToolButton;
-class KIntNumInput;
 class KMAccount;
 class KMFolder;
 class QButtonGroup;
-class QGroupBox;
 
 namespace MailTransport {
 class ServerTest;
@@ -113,7 +106,8 @@ class AccountDialog : public KDialog
     void slotFilterOnServerClicked();
     void slotPipeliningClicked();
     void slotPopEncryptionChanged(int);
-    void slotPopPasswordChanged(const QString& text);
+    void slotPopPasswordChanged( const QString& text );
+    void slotImapPasswordChanged( const QString& text );
     void slotImapEncryptionChanged(int);
     void slotCheckPopCapabilities();
     void slotCheckImapCapabilities();
