@@ -35,8 +35,7 @@
 #define __KMAIL_BODYPARTFORMATTERFACTORY_H__
 
 class QString;
-class QCString;
-
+#include <QByteArray>
 namespace KMail {
 
   namespace Interface {
@@ -53,7 +52,7 @@ namespace KMail {
 
     const Interface::BodyPartFormatter * createFor( const char * type, const char * subtype ) const;
     const Interface::BodyPartFormatter * createFor( const QString & type, const QString & subtype ) const;
-    const Interface::BodyPartFormatter * createFor( const QCString & type, const QCString & subtype ) const;
+    const Interface::BodyPartFormatter * createFor( const QByteArray & type, const QByteArray & subtype ) const;
 
     //
     // Only boring stuff below:
