@@ -32,8 +32,10 @@
 #include "ui_customtemplates_base.h"
 #include "ui_miscpagemaintab.h"
 #include "ui_miscpagegroupwaretab.h"
+#include "ui_miscpageinvitetab.h"
 #include "ui_securitypagegeneraltab.h"
 #include "ui_identitypage.h"
+#include "ui_accountspagereceivingtab.h"
 
 class QPushButton;
 class QLabel;
@@ -50,7 +52,6 @@ class KButtonGroup;
 class KUrlRequester;
 class KFontChooser;
 class KTabWidget;
-class KVBox;
 class KMAccount;
 class ListView;
 class ConfigureDialog;
@@ -67,12 +68,16 @@ class KIconButton;
 class KKeySequenceWidget;
 class KComboBox;
 
+namespace MessageList {
+  namespace Utils {
+    class AggregationComboBox;
+    class ThemeComboBox;
+  }
+}
 namespace KMail {
   class IdentityDialog;
   class IdentityListView;
   class IdentityListViewItem;
-  class AccountComboBox;
-  class FolderRequester;
 }
 namespace Kleo {
   class BackendConfigWidget;
@@ -132,32 +137,6 @@ private:
   QButtonGroup *mButtonGroup;
 };
 
-//
-//
-// Profile dialog
-//
-//
-
-class ProfileDialog : public KDialog {
-  Q_OBJECT
-public:
-  ProfileDialog( QWidget * parent=0 );
-
-signals:
-  void profileSelected( KConfig * profile );
-
-private slots:
-  void slotSelectionChanged();
-  void slotOk();
-
-private:
-  void setup();
-
-private:
-  QTreeWidget *mListView;
-  QStringList mProfileList;
-};
-
 #include <kvbox.h>
 class ConfigModule : public KCModule {
   Q_OBJECT
@@ -173,15 +152,6 @@ public:
 
   /** Should return the help anchor for this page or tab */
   virtual QString helpAnchor() const = 0;
-
-signals:
-  /** Emitted when the installation of a profile is
-      requested. All connected kcms should load the values
-      from the profile only for those entries that
-      really have keys defined in the profile.
-   */
-   void installProfile( KConfig * profile );
-
 };
 
 
@@ -196,8 +166,6 @@ public:
   void load();
   virtual void save() = 0;
   void defaults();
-  // the below are optional
-  virtual void installProfile( KConfig* ) {};
 signals:
    // forwarded to the ConfigModule
   void changed(bool);
@@ -230,7 +198,6 @@ public:
   virtual void load();
   virtual void save();
   virtual void defaults();
-  virtual void installProfile( KConfig * profile );
 
 protected:
   void addTab( ConfigModuleTab* tab, const QString & title );
@@ -337,14 +304,7 @@ private:
   QStringList occupiedNames();
 
 private:
-  ListView      *mAccountList;
-  QPushButton   *mModifyAccountButton;
-  QPushButton   *mRemoveAccountButton;
-  QCheckBox     *mBeepNewMailCheck;
-  QCheckBox     *mVerboseNotificationCheck;
-  QCheckBox     *mCheckmailStartupCheck;
-  QPushButton   *mOtherNewMailActionsButton;
-
+  Ui_AccountsPageReceivingTab mAccountsReceiving;
   QList< QPointer<KMAccount> > mAccountsToDelete;
   QList< QPointer<KMAccount> > mNewAccounts;
   struct ModifiedAccountsType {
@@ -388,8 +348,6 @@ public:
   QString helpAnchor() const;
   void save();
 
-  void installProfile( KConfig * profile );
-
 private slots:
   void slotFontSelectorChanged( int );
 
@@ -405,7 +363,7 @@ private:
   KFontChooser *mFontChooser;
 
   int          mActiveFontIndex;
-  QFont        mFont[14];
+  QFont        mFont[13];
 };
 
 class AppearancePageColorsTab : public ConfigModuleTab {
@@ -415,8 +373,6 @@ public:
   QString helpAnchor() const;
   void save();
 
-  void installProfile( KConfig * profile );
-
 private:
   //virtual void doLoadFromGlobalSettings();
   virtual void doLoadOther();
@@ -436,7 +392,6 @@ public:
   QString helpAnchor() const;
 
   void save();
-  void installProfile( KConfig * profile );
 
 private:
   //virtual void doLoadFromGlobalSettings();
@@ -446,14 +401,12 @@ private:
 private: // data
   QButtonGroup  *mFolderListGroup;
   QGroupBox     *mFolderListGroupBox;
-  QButtonGroup  *mMIMETreeLocationGroup;
-  QGroupBox     *mMIMETreeLocationGroupBox;
-  QButtonGroup  *mMIMETreeModeGroup;
-  QGroupBox     *mMIMETreeModeGroupBox;
   QButtonGroup  *mReaderWindowModeGroup;
   QGroupBox     *mReaderWindowModeGroupBox;
   QCheckBox     *mFavoriteFolderViewCB;
   QCheckBox     *mFolderQuickSearchCB;
+  QButtonGroup  *mFolderToolTipsGroup;
+  QGroupBox     *mFolderToolTipsGroupBox;
 };
 
 class AppearancePageHeadersTab : public ConfigModuleTab {
@@ -464,7 +417,6 @@ public:
   QString helpAnchor() const;
 
   void save();
-  void installProfile( KConfig * profile );
 
 private: // methods
   //virtual void doLoadFromGlobalSettings();
@@ -475,12 +427,16 @@ private: // methods
 private: // data
   QCheckBox    *mDisplayMessageToolTips;
   QCheckBox    *mHideTabBarWithSingleTab;
+  MessageList::Utils::AggregationComboBox *mAggregationComboBox;
+  MessageList::Utils::ThemeComboBox *mThemeComboBox;
   KButtonGroup *mDateDisplay;
   KLineEdit    *mCustomDateFormatEdit;
   QString       mCustomDateWhatsThis;
 
 private slots:
   void slotLinkClicked( const QString & link );
+  void slotSelectDefaultAggregation();
+  void slotSelectDefaultTheme();
 };
 
 class AppearancePageReaderTab : public ConfigModuleTab {
@@ -491,7 +447,6 @@ public:
   QString helpAnchor() const;
 
   void save();
-  void installProfile( KConfig * profile );
 
 private:
   virtual void doLoadFromGlobalSettings();
@@ -520,7 +475,6 @@ public:
   QString helpAnchor() const;
 
   void save();
-  void installProfile( KConfig * profile );
 
 private:
   virtual void doLoadFromGlobalSettings();
@@ -541,7 +495,6 @@ public:
   QString helpAnchor() const;
 
   void save();
-  void installProfile( KConfig * profile );
 
 public slots:
   /**Enables/disables Add button according to whether @p aText is empty.
@@ -592,12 +545,12 @@ private: // data
 
   QListWidget *mTagListBox;
 
-  QCheckBox *mTextColorCheck,
+  QCheckBox *mTextColorCheck, *mBackgroundColorCheck,
             *mTextFontCheck, *mInToolbarCheck;
 
   QGroupBox *mTagsGroupBox, *mTagSettingGroupBox;
 
-  KColorCombo *mTextColorCombo;
+  KColorCombo *mTextColorCombo, *mBackgroundColorCombo;
 
   KFontRequester *mFontRequester;
 
@@ -652,7 +605,6 @@ public:
   QString helpAnchor() const;
 
   void save();
-  void installProfile( KConfig * profile );
 protected slots:
   void slotConfigureRecentAddresses();
   void slotConfigureCompletionOrder();
@@ -844,7 +796,6 @@ public:
   QString helpAnchor() const;
 
   void save();
-  void installProfile( KConfig * profile );
 
 private:
   //virtual void doLoadFromGlobalSettings();
@@ -869,7 +820,6 @@ public:
   QString helpAnchor() const;
 
   void save();
-  void installProfile( KConfig * profile );
 
 private:
   //virtual void doLoadFromGlobalSettings();
@@ -888,11 +838,9 @@ public:
   QString helpAnchor() const;
 
   void save();
-  void installProfile( KConfig * profile );
 
 private slots:
   void slotReenableAllWarningsClicked();
-  void updateSpinBoxSuffix();
 
 private:
   //virtual void doLoadFromGlobalSettings();
@@ -912,7 +860,6 @@ public:
   QString helpAnchor() const;
 
   void save();
-  void installProfile( KConfig * profile );
 
 private slots:
   void slotUpdateHTTPActions();
@@ -953,9 +900,6 @@ public:
 
   QString helpAnchor() const;
 
-  // OpenPGP tab is special:
-  void installProfile( KConfig * profile );
-
   typedef SecurityPageGeneralTab GeneralTab;
   typedef SecurityPageComposerCryptoTab ComposerCryptoTab;
   typedef SecurityPageWarningTab WarningTab;
@@ -1003,7 +947,6 @@ public:
 
 private slots:
   void slotStorageFormatChanged( int );
-  void slotLegacyBodyInvitesToggled( bool on );
 
 private:
   virtual void doLoadFromGlobalSettings();
@@ -1012,6 +955,23 @@ private:
   Ui_MiscGroupTab mMGTab;
 };
 
+class MiscPageInviteTab : public ConfigModuleTab  {
+  Q_OBJECT
+public:
+  MiscPageInviteTab( QWidget * parent=0 );
+  void save();
+  QString helpAnchor() const;
+
+private slots:
+  void slotLegacyBodyInvitesToggled( bool on );
+
+private:
+  virtual void doLoadFromGlobalSettings();
+
+private:
+  Ui_MiscInviteTab mMITab;
+};
+
 class KMAIL_EXPORT MiscPage : public ConfigModuleWithTabs {
   Q_OBJECT
 public:
@@ -1020,33 +980,12 @@ public:
 
   typedef MiscPageFolderTab FolderTab;
   typedef MiscPageGroupwareTab GroupwareTab;
+  typedef MiscPageInviteTab InviteTab;
 
 private:
   FolderTab * mFolderTab;
   GroupwareTab * mGroupwareTab;
+  InviteTab * mInviteTab;
 };
 
-//
-//
-// further helper classes:
-//
-//
-
-class ListView : public QTreeWidget {
-  Q_OBJECT
-public:
-  explicit ListView( QWidget *parent=0 );
-  void resizeColums();
-
-  virtual QSize sizeHint() const;
-
-protected:
-  virtual void resizeEvent( QResizeEvent *e );
-  virtual void showEvent( QShowEvent *e );
-
-private:
-  int mVisibleItem;
-};
-
-
 #endif // _CONFIGURE_DIALOG_PRIVATE_H_
