@@ -17,6 +17,7 @@
 */
 
 #include "editorwatcher.h"
+#include "autoqpointer.h"
 
 #include <config-kmail.h>
 
@@ -42,12 +43,14 @@
 
 using namespace KMail;
 
-EditorWatcher::EditorWatcher(const KUrl & url, const QString &mimeType, bool openWith, QObject * parent) :
+EditorWatcher::EditorWatcher( const KUrl & url, const QString &mimeType, bool openWith,
+                              QObject * parent, QWidget *parentWidget ) :
     QObject( parent ),
     mUrl( url ),
     mMimeType( mimeType ),
     mOpenWith( openWith ),
     mEditor( 0 ),
+    mParentWidget( parentWidget ),
     mHaveInotify( false ),
     mFileOpen( false ),
     mEditorRunning( false ),
@@ -66,11 +69,13 @@ bool EditorWatcher::start()
   list.append( mUrl );
   KService::Ptr offer = KMimeTypeTrader::self()->preferredService( mMimeType, "Application" );
   if ( mOpenWith || !offer ) {
-    KOpenWithDialog dlg( list, i18n("Edit with:"), QString(), 0 );
-    if ( !dlg.exec() )
-      return false;
-    offer = dlg.service();
-    if ( !offer )
+    AutoQPointer<KOpenWithDialog> dlg( new KOpenWithDialog( list, i18n("Edit with:"),
+                                                            QString(), 0 ) );
+    int dlgrc = dlg->exec();
+    if ( dlgrc && dlg ) {
+      offer = dlg->service();
+    }
+    if ( !dlgrc || !offer )
       return false;
   }
 
@@ -86,7 +91,7 @@ bool EditorWatcher::start()
       mFileModified = false;
     }
   } else {
-    kWarning(5006) <<"Failed to activate INOTIFY!";
+    kWarning() <<"Failed to activate INOTIFY!";
   }
 #endif
 
@@ -151,8 +156,11 @@ void EditorWatcher::checkEditDone()
   // nobody can edit that fast, we seem to be unable to detect
   // when the editor will be closed
   if ( mEditTime.elapsed() <= 3000 ) {
-    KMessageBox::error( 0, i18n("KMail is unable to detect when the chosen editor is closed. "
-         "To avoid data loss, editing the attachment will be aborted."), i18n("Unable to edit attachment") );
+    KMessageBox::information( mParentWidget,
+                        i18n( "KMail is unable to detect when the chosen editor is closed. "
+                              "To avoid data loss, editing the attachment will be aborted." ),
+                        i18n( "Unable to edit attachment" ),
+                        "UnableToEditAttachment" );
   }
 
   emit editDone( this );
