@@ -263,7 +263,7 @@ void FolderView::readConfig()
   else
     setFont( KGlobalSettings::generalFont() );
 
-  if ( !restoreLayout( KMKernel::config(), "Geometry", mConfigPrefix + "Layout" ) )
+  if ( !restoreLayout( KMKernel::config().data(), "Geometry", mConfigPrefix + "Layout" ) )
   {
     // hide all the columns but the first (the default)
     setColumnHidden( DataSizeColumn, true );
@@ -291,7 +291,7 @@ void FolderView::readConfig()
 void FolderView::writeConfig()
 {
   saveItemStates();
-  saveLayout( KMKernel::config(), "Geometry", mConfigPrefix + "Layout" );
+  saveLayout( KMKernel::config().data(), "Geometry", mConfigPrefix + "Layout" );
 
   KConfigGroup myGroup( KMKernel::config(), mConfigPrefix );
   myGroup.writeEntry( "IconSize", iconSize().width() );
@@ -385,7 +385,8 @@ void FolderView::restoreItemStates()
 
     KConfigGroup conf( KMKernel::config(), mit.key() );
 
-    fvi->setExpanded( conf.readEntry( mConfigPrefix + "ItemIsExpanded", false ) );
+    if ( conf.hasKey( mConfigPrefix + "ItemIsExpanded" ) )
+      fvi->setExpanded( conf.readEntry( mConfigPrefix + "ItemIsExpanded", false ) );
     fvi->setSelected( conf.readEntry( mConfigPrefix + "ItemIsSelected", false ) );
     fvi->setDndSortingKey( conf.readEntry( mConfigPrefix + "ItemDnDSortingKey", -1 ) );
   }
@@ -399,7 +400,7 @@ void FolderView::cleanupConfigFile()
   if ( topLevelItemCount() == 0 )
     return; // just in case reload wasn't called before
 
-  KConfig* config = KMKernel::config();
+  KSharedConfig::Ptr config = KMKernel::config();
   FolderViewItem * fvi;
   QHash<QString,bool> folderMap;
 
@@ -627,6 +628,11 @@ void FolderView::reload( bool openFoldersForUpdate )
   // note that root MIGHT be 0 here (if the view filtered it out)
   addDirectory( false, &( kmkernel->folderMgr()->dir() ), root );
 
+  // make a better first impression by showing the "Local Folders" expanded per default
+  // Further down the last saved state (expanded/collapsed) will be restored
+  if ( root )
+    root->setExpanded( true );
+
   // each imap-account creates it's own root
   addDirectory( true, &( kmkernel->imapFolderMgr()->dir() ), 0);
 
@@ -1106,13 +1112,13 @@ bool FolderView::event( QEvent *e )
   if( e->type() != QEvent::ToolTip )
     return KPIM::FolderTreeWidget::event( e );
 
+  if ( mToolTipDisplayPolicy == DisplayNever )
+    return true; // never display tooltips
+
   QHelpEvent * he = dynamic_cast< QHelpEvent * >( e );
   if ( !he )
     return true; // eh ?
 
-  if ( mToolTipDisplayPolicy == DisplayNever )
-    return true; // never display tooltips
-
   QPoint pnt = viewport()->mapFromGlobal( mapToGlobal( he->pos() ) );
 
   if ( pnt.y() < 0 )
@@ -1335,6 +1341,9 @@ void FolderView::slotHeaderContextMenuChangeToolTipDisplayPolicy( bool )
     return;
 
   setToolTipDisplayPolicy( ( ToolTipDisplayPolicy )policy );
+
+  // stay in sync with ConfigureDialog
+  writeConfig();
 }
 
 void FolderView::slotHeaderContextMenuChangeIconSize( bool )
@@ -1470,6 +1479,8 @@ void FolderView::fillContextMenuFolderServiceRelatedActions( KMenu *menu, Folder
         );
   }
 
+  menu->addAction( mMainWidget->action( "archive_folder" ) );
+
   // compaction is only supported for mbox folders
   // see FolderDialogMaintenanceTab::FolderDialogMaintenanceTab()
   if ( folder->folderType() == KMFolderTypeMbox )
@@ -1478,7 +1489,7 @@ void FolderView::fillContextMenuFolderServiceRelatedActions( KMenu *menu, Folder
   if ( item->folderType() != FolderViewItem::Root ) // non account level folder
   {
     menu->addAction( mMainWidget->action( "folder_shortcut_command" ) );
-    if ( !folder->noContent() )
+    if ( !folder->noContent() && folder->canDeleteMessages())
       menu->addAction( i18n("Expire..."), item, SLOT( slotShowExpiryProperties() ) );
 
     // properties
@@ -1846,7 +1857,9 @@ bool FolderView::selectFolderIfUnread(FolderViewItem *fvi, bool confirm)
   if (
        !(
          fvi && fvi->folder() &&
-         ( !fvi->folder()->ignoreNewMail() ) &&
+         ( !fvi->folder()->ignoreNewMail() ||     // loop only in marked folders
+           ( GlobalSettings::self()->loopOnGotoUnread() ==
+             GlobalSettings::EnumLoopOnGotoUnread::LoopInAllFolders ) ) &&   // loop in all folders
          ( fvi->folder()->countUnread() > 0 )
         )
      )
@@ -1891,7 +1904,7 @@ bool FolderView::selectFolderIfUnread(FolderViewItem *fvi, bool confirm)
            i18n( "Go to Next Unread Message" ),
            KGuiItem( i18n( "Go To" ) ),
            KGuiItem( i18n( "Do Not Go To" ) ), // defaults
-           "AskNextFolder",
+           ":kmail_AskNextFolder",
            false
          ) == KMessageBox::No
      )
