@@ -268,6 +268,7 @@ KMFilterDlg::KMFilterDlg(QWidget* parent, bool popFilter, bool createDummyFilter
       mKeySeqWidget->setObjectName( "FilterShortcutSelector" );
       gl->addWidget( mKeySeqWidget, 8, 3, 1, 1);
       mKeySeqWidget->setEnabled( false );
+      mKeySeqWidget->setModifierlessAllowed( true );
       mKeySeqWidget->setCheckActionCollections(
                              kmkernel->getKMMainWidget()->actionCollections() );
       mConfigureToolbar = new QCheckBox( i18n("Additionally add this filter to the toolbar"), mAdvOptsGroup );
@@ -763,7 +764,7 @@ void KMFilterListBox::slotUpdateFilterName()
 
   if ( mFilterList.at(mIdxSelItem)->isAutoNaming() ) {
     // auto-naming of patterns
-    if ( p->first() && !p->first()->field().trimmed().isEmpty() )
+    if ( !p->isEmpty() && p->first() && !p->first()->field().trimmed().isEmpty() )
       shouldBeName = QString( "<%1>: %2" ).arg( QString::fromLatin1( p->first()->field() ) ).arg( p->first()->contents() );
     else
       shouldBeName = '<' + i18n("unnamed") + '>';
