@@ -57,6 +57,10 @@ namespace KMail {
 }
 using KMail::AttachmentStrategy;
 
+namespace QIndicate {
+  class Indicator;
+}
+
 typedef QList<quint32> SerNumList;
 
 /** Mail folder.
@@ -385,6 +389,8 @@ public:
 
   /** Is the folder read-only? */
   bool isReadOnly() const;
+  /** Can we write into and delete from this folder (on IMAP that's not necessarily !isReadOnly()) */
+  bool isWritable() const;
 
   /** Can messages in this folder be deleted? */
   bool canDeleteMessages() const;
@@ -394,15 +400,15 @@ public:
     The name of these folders is nationalized in the folder display and
     they cannot have accounts associated. Deletion is also forbidden. Etc. */
   bool isSystemFolder() const { return mIsSystemFolder; }
-  void setSystemFolder(bool itIs) { mIsSystemFolder = itIs; }
+  void setSystemFolder( bool itIs );
 
   /** Returns the label of the folder for visualization. */
   virtual QString label() const;
-  void setLabel( const QString& l ) { mLabel = l; }
+  void setLabel( const QString& l );
 
   /** Set the label that is used as a system default */
   virtual QString systemLabel() const { return mSystemLabel; }
-  void setSystemLabel( const QString& l ) { mSystemLabel = l; }
+  void setSystemLabel( const QString& l );
 
   /** URL of the node for visualization purposes. */
   virtual QString prettyUrl() const;
@@ -557,12 +563,18 @@ public:
   bool putRepliesInSameFolder() const { return mPutRepliesInSameFolder; }
   void setPutRepliesInSameFolder( bool b ) { mPutRepliesInSameFolder = b; }
 
+  /**
+   * Returns true if this folder should be hidden from all folder selection dialogs
+   */
+  bool hideInSelectionDialog() const { return mHideInSelectionDialog; }
+  void setHideInSelectionDialog( bool hide ) { mHideInSelectionDialog = hide; }
+
   /**
    * Returns true if the user doesn't want to get notified about new mail
    * in this folder.
    */
   bool ignoreNewMail() const { return mIgnoreNewMail; }
-  void setIgnoreNewMail( bool b ) { mIgnoreNewMail = b; }
+  void setIgnoreNewMail( bool b );
 
   const KShortcut &shortcut() const { return mShortcut; }
   void setShortcut( const KShortcut& );
@@ -578,6 +590,13 @@ public:
   /** Sets the move-in-progress flag. */
   void setMoveInProgress( bool b ) { mMoveInProgress = b; }
 
+  /**
+  * Returns true if the name is valid for a child of this folder.
+  * If the name contains invalid characters then false is returned and message will contain
+  * an explanation that can be presented to the user.
+  */
+  bool isValidName( const QString &folderName, QString &message );
+
 signals:
   /** Emitted when the status, name, or associated accounts of this
     folder changed. */
@@ -668,6 +687,12 @@ private slots:
    *  to the default identity if the current one became invalid. */
   void slotIdentitiesChanged();
 
+  void updateIndicatorCount();
+  void updateIndicatorText();
+  void updateIndicatorIcon();
+
+  void slotIndicatorClicked();
+
 private:
   FolderStorage* mStorage;
   KMFolderDir* mChild;
@@ -709,11 +734,16 @@ private:
   /** Should replies to messages in this folder be put in here? */
   bool mPutRepliesInSameFolder;
 
+  /** Should this folder be hidden in the folder selection dialog? */
+  bool mHideInSelectionDialog;
+
   /** Should new mail in this folder be ignored? */
   bool mIgnoreNewMail;
 
   /** shortcut associated with this folder or null, if none is configured. */
   KShortcut mShortcut;
+
+  QIndicate::Indicator* mIndicator;
 };
 
 /**
