@@ -36,6 +36,7 @@
 #include "kmmsgpart.h"
 #include "kmkernel.h"
 #include "kmcommands.h"
+#include "kmfolder.h"
 
 #include <kdebug.h>
 #include <klocale.h>
@@ -95,7 +96,7 @@ static const char configEntry[] = "State";
 
 KMMimePartTree::~KMMimePartTree()
 {
-  saveLayout( KMKernel::config(), configGroup, configEntry );
+  saveLayout( KMKernel::config().data(), configGroup, configEntry );
 }
 
 void KMMimePartTree::clearAndResetSortOrder()
@@ -108,7 +109,7 @@ void KMMimePartTree::clearAndResetSortOrder()
 
 void KMMimePartTree::restoreLayoutIfPresent()
 {
-  if ( restoreLayout( KMKernel::config(), configGroup, configEntry ) )
+  if ( restoreLayout( KMKernel::config().data(), configGroup, configEntry ) )
     return;
   // No configGroup or no configEntry.
   // Provide nice defaults on first show
@@ -183,17 +184,22 @@ void KMMimePartTree::slotContextMenuRequested( const QPoint& p )
                    SLOT( slotSaveAsEncoded() ) );
   */
 
-  popup.addAction( i18n( "Save All Attachments..." ), this,
-                   SLOT( slotSaveAll() ) );
+  if ( topLevelItemCount() > 0) {
+    popup.addAction( i18n( "Save All Attachments..." ), this,
+                     SLOT( slotSaveAll() ) );
+  }
 
   // edit + delete only for attachments
   if ( !isRoot ) {
     if ( isAttachment ) {
       popup.addAction( SmallIcon( "edit-copy" ), i18n( "Copy" ),
                        this, SLOT( slotCopy() ) );
-      if ( GlobalSettings::self()->allowAttachmentDeletion() )
-        popup.addAction( SmallIcon( "edit-delete" ), i18n( "Delete Attachment" ),
+      if ( GlobalSettings::self()->allowAttachmentDeletion() ) {
+        QAction *act = popup.addAction( SmallIcon( "edit-delete" ), i18n( "Delete Attachment" ),
                          this, SLOT( slotDelete() ) );
+        const bool canChange = mReaderWin->message()->parent() ? !mReaderWin->message()->parent()->isReadOnly() : false;
+        act->setEnabled( canChange );
+      }
       if ( GlobalSettings::self()->allowAttachmentEditing() )
         popup.addAction( SmallIcon( "document-properties" ), i18n( "Edit Attachment" ),
                          this, SLOT( slotEdit() ) );
@@ -202,7 +208,8 @@ void KMMimePartTree::slotContextMenuRequested( const QPoint& p )
     if ( item && item->node()->nodeId() > 0 )
       popup.addAction( i18n( "Properties" ), this, SLOT( slotProperties() ) );
   }
-  popup.exec( viewport()->mapToGlobal( p ) );
+  if ( !popup.isEmpty() )
+    popup.exec( viewport()->mapToGlobal( p ) );
 }
 
 //-----------------------------------------------------------------------------
