@@ -55,15 +55,12 @@ KMPopHeadersView::KMPopHeadersView( QWidget *parent,
               << i18nc("@title:column", "Sender") << i18nc("@title:column", "Receiver")
               << i18nc("@title:column", "Date") << i18nc("@title:column", "Size");
   QTreeWidgetItem *headerItem = new QTreeWidgetItem( headerNames );
-  headerItem->setTextAlignment( 0, Qt::AlignHCenter );
-  headerItem->setTextAlignment( 1, Qt::AlignHCenter );
-  headerItem->setTextAlignment( 2, Qt::AlignHCenter );
   headerItem->setTextAlignment( 7, Qt::AlignRight );
   headerItem->setToolTip( 0, i18nc("@action:button", "Download all messages now") );
   headerItem->setToolTip( 1, i18nc("@action:button", "Download all messages later") );
   headerItem->setToolTip( 2, i18nc("@action:button", "Delete all messages") );
-  headerItem->setIcon( 0, KIcon( "mail-download-now" ) );
-  headerItem->setIcon( 1, KIcon( "mail-download-later" ) );
+  headerItem->setIcon( 0, KIcon( "download" ) );
+  headerItem->setIcon( 1, KIcon( "download-later" ) );
   headerItem->setIcon( 2, KIcon( "edit-delete" ) );
   setHeaderItem( headerItem );
   header()->setResizeMode( QHeaderView::Interactive );
@@ -76,9 +73,9 @@ KMPopHeadersView::KMPopHeadersView( QWidget *parent,
   //    Disable it for now.
   //header()->setResizeMode( 3, QHeaderView::Stretch );
   header()->setStretchLastSection( false );
-  setColumnWidth( 0, 22 );    // Download Now icon
-  setColumnWidth( 1, 22 );    // Download Later icon
-  setColumnWidth( 2, 22 );    // Delete icon
+  setColumnWidth( 0, IconSize( KIconLoader::Small ) + 6 );    // Download Now icon
+  setColumnWidth( 1, IconSize( KIconLoader::Small ) + 6 );    // Download Later icon
+  setColumnWidth( 2, IconSize( KIconLoader::Small ) + 6 );    // Delete icon
   setColumnWidth( 3, 180 );   // Subject
   setColumnWidth( 4, 140 );   // Sender
   setColumnWidth( 5, 140);    // Receiver
@@ -150,7 +147,8 @@ void KMPopHeadersView::keyPressEvent( QKeyEvent *e )
   }
 }
 
-void KMPopHeadersView::slotRadioButtonClicked( QTreeWidgetItem* item, int column ) {
+void KMPopHeadersView::slotRadioButtonClicked( QTreeWidgetItem* item, int column )
+{
   assert( item && column >= 0 && column < NoAction );
   mDialog->setAction( item, mapToAction( column ) );
 
@@ -296,6 +294,7 @@ KMPopFilterCnfrmDlg::KMPopFilterCnfrmDlg( const QList<KMPopHeaders *> & headers,
   setUpdatesEnabled( false );
   setCaption( i18nc("@title:window", "POP Filter") );
   setButtons( Ok | Help | Cancel );
+  setButtonFocus( Ok );
   setHelp( "popfilters" );
   unsigned int rulesetCount = 0;
   mShowLaterMsgs = showLaterMsgs;
@@ -309,7 +308,7 @@ KMPopFilterCnfrmDlg::KMPopFilterCnfrmDlg( const QList<KMPopHeaders *> & headers,
   mainLayout->setMargin( 0 );
 
   QLabel *infoLabel = new QLabel(
-            i18nc( "@info/plain", "<title>Messages to filter found on POP Account: <emphasis>%1</emphasis></title>"
+            i18nc( "@info", "<title>Messages to filter found on POP Account: <emphasis>%1</emphasis></title>"
                   "<para>The messages shown exceed the maximum size limit you defined "
                   "for this account.</para><para>You can select what you want to do "
                   "with them by checking the appropriate button.</para>",
