@@ -45,7 +45,7 @@ namespace KMail {
   SieveJob::~SieveJob() {
     kill();
     delete mDec;
-    kDebug(5006) <<"~SieveJob()";
+    kDebug() << "~SieveJob()";
   }
 
   void SieveJob::kill( KJob::KillVerbosity verbosity ) {
@@ -62,41 +62,41 @@ namespace KMail {
   void SieveJob::schedule( Command command ) {
     switch ( command ) {
     case Get:
-      kDebug(5006) << "get(" << mUrl.prettyUrl() <<" )";
+      kDebug() << "get(" << mUrl.prettyUrl() << ")";
       mJob = KIO::get( mUrl );
       connect( mJob, SIGNAL(data(KIO::Job*,const QByteArray&)),
                SLOT(slotData(KIO::Job*,const QByteArray&)) );
       break;
     case Put:
-      kDebug(5006) << "put(" << mUrl.prettyUrl() <<" )";
+      kDebug() << "put(" << mUrl.prettyUrl() << ")";
       mJob = KIO::put( mUrl, 0600, KIO::Overwrite );
       connect( mJob, SIGNAL(dataReq(KIO::Job*,QByteArray&)),
                SLOT(slotDataReq(KIO::Job*,QByteArray&)) );
       break;
     case Activate:
-      kDebug(5006) << "chmod(" << mUrl.prettyUrl() <<", 0700 )";
+      kDebug() << "chmod(" << mUrl.prettyUrl() <<", 0700 )";
       mJob = KIO::chmod( mUrl, 0700 );
       break;
     case Deactivate:
-      kDebug(5006) << "chmod(" << mUrl.prettyUrl() <<", 0600 )";
+      kDebug() << "chmod(" << mUrl.prettyUrl() <<", 0600 )";
       mJob = KIO::chmod( mUrl, 0600 );
       break;
     case SearchActive:
-      kDebug(5006) << "listDir(" << mUrl.prettyUrl() <<" )";
+      kDebug() << "listDir(" << mUrl.prettyUrl() << ")";
       {
         KUrl url = mUrl;
         QString query = url.query(); //save query part, because KUrl::cd() erases it
         if ( !url.fileName().isEmpty() )
           url.cd("..");
         url.setQuery( query );
-        kDebug(5006) << "listDir's real URL:" << url.prettyUrl();
+        kDebug() << "listDir's real URL:" << url.prettyUrl();
         mJob = KIO::listDir( url );
         connect( mJob, SIGNAL(entries(KIO::Job*,const KIO::UDSEntryList&)),
                  SLOT(slotEntries(KIO::Job*,const KIO::UDSEntryList&)) );
         break;
       }
     case List:
-      kDebug(5006) << "listDir(" << mUrl.prettyUrl() <<" )";
+      kDebug() << "listDir(" << mUrl.prettyUrl() << ")";
       {
         mJob = KIO::listDir( mUrl );
         connect( mJob, SIGNAL( entries(KIO::Job *, const KIO::UDSEntryList & ) ),
@@ -104,7 +104,7 @@ namespace KMail {
         break;
       }
     case Delete:
-      kDebug(5006) << "delete(" << mUrl.prettyUrl() <<" )";
+      kDebug() << "delete(" << mUrl.prettyUrl() << ")";
       mJob = KIO::del( mUrl );
       break;
     default:
@@ -180,7 +180,7 @@ namespace KMail {
 
     if ( mSieveCapabilities.empty() ) {
       mSieveCapabilities = static_cast<KIO::Job*>(job)->queryMetaData( "sieveExtensions" ).split(' ', QString::SkipEmptyParts );
-      kDebug(5006) <<"Received Sieve extensions supported:\n" << mSieveCapabilities.join("\n");
+      kDebug() << "Received Sieve extensions supported:\n" << mSieveCapabilities.join("\n");
     }
 
     // check for errors:
@@ -204,7 +204,7 @@ namespace KMail {
 
     // check for new tasks:
     if ( !mCommands.empty() ) {
-      // Don't fail get'ting a non-existant script:
+      // Don't fail getting a non-existent script:
       if ( mCommands.top() == Get && mFileExists == No ) {
 	mScript.clear();
 	mCommands.pop();
@@ -257,6 +257,12 @@ namespace KMail {
     return new SieveJob( url, QString(), commands );
   }
 
+  SieveJob * SieveJob::desactivate( const KUrl & url ) {
+    QStack<Command> commands;
+    commands.push( Deactivate );
+    return new SieveJob( url, QString(), commands );
+  }
+
   SieveJob * SieveJob::activate( const KUrl & url ) {
     QStack<Command> commands;
     commands.push( Activate );
