@@ -106,6 +106,15 @@ namespace Util {
      */
     DwString dwString( const QByteArray& str );
 
+
+    /**
+     * Validates a list of email addresses.
+     * @return true if all addresses are valid.
+     * @return false if one or several addresses are invalid.
+     */
+    bool validateAddresses( QWidget *parent, const QString &addresses );
+
+
     /**
      * A LaterDeleter is intended to be used with the RAII ( Resource
      * Acquisiation is Initialization ) paradigm. When an instance of it
@@ -135,21 +144,6 @@ namespace Util {
       bool m_disabled;
     };
 
-    /**
-      * Small helper class that implements a variable when it is constructed and decrements that
-      * when it is destructed.
-      * Intended use is to use this with a static int that is initialy 0.
-      */
-    class RecursionPreventer
-    {
-      public:
-        explicit RecursionPreventer( int &counter );
-        ~RecursionPreventer();
-        bool isRecursive() const;
-
-      private:
-        int &mCounter;
-    };
 
 }
 }
