@@ -1,7 +1,7 @@
 /*
  *  filter_evolution.cxx
  *  Author : Simon MARTIN <simartin@users.sourceforge.net>
- *  Copyright (c) 2004 Simon MARTIN
+ *  Copyright (c) 2004 Simon MARTIN <simartin@users.sourceforge.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,7 +38,6 @@ FilterEvolution::FilterEvolution(void) :
 /** Destructor. */
 FilterEvolution::~FilterEvolution(void)
 {
-    endImport();
 }
 
 /** Recursive import of Evolution's mboxes. */
@@ -66,9 +65,9 @@ void FilterEvolution::import(FilterInfo *info)
         info->setOverall(0);
         // Recursive import of the MBoxes.
         QDir dir(mailDir);
-        QStringList rootSubDirs = dir.entryList(QStringList("[^\\.]*"), QDir::Dirs, QDir::Name); // Removal of . and ..
+        const QStringList rootSubDirs = dir.entryList(QStringList("[^\\.]*"), QDir::Dirs, QDir::Name); // Removal of . and ..
         int currentDir = 1, numSubDirs = rootSubDirs.size();
-        for(QStringList::Iterator filename = rootSubDirs.begin() ; filename != rootSubDirs.end() ; ++filename, ++currentDir) {
+        for(QStringList::ConstIterator filename = rootSubDirs.constBegin() ; filename != rootSubDirs.constEnd() ; ++filename, ++currentDir) {
             importDirContents(info, dir.filePath(*filename), *filename, QString());
             info->setOverall((int) ((float) currentDir / numSubDirs * 100));
         }
@@ -95,8 +94,8 @@ void FilterEvolution::importDirContents(FilterInfo *info, const QString& dirName
     // If there are subfolders, we import them one by one
     if(dir.exists("subfolders")) {
         QDir subfolders(dirName + "/subfolders");
-        QStringList subDirs = subfolders.entryList(QStringList("[^\\.]*"), QDir::Dirs, QDir::Name);
-        for(QStringList::Iterator filename = subDirs.begin() ; filename != subDirs.end() ; ++filename) {
+        const QStringList subDirs = subfolders.entryList(QStringList("[^\\.]*"), QDir::Dirs, QDir::Name);
+        for(QStringList::ConstIterator filename = subDirs.constBegin() ; filename != subDirs.constEnd() ; ++filename) {
             QString kSubDir;
             if(!KMailSubDir.isNull()) {
                 kSubDir = KMailSubDir + '/' + *filename;
@@ -198,3 +197,4 @@ void FilterEvolution::importMBox(FilterInfo *info, const QString& mboxName, cons
         mbox.close();
     }
 }
+
