@@ -11,6 +11,11 @@
     Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
 */
 
+#include "articlewidget.h"
+
+#include "utils/locale.h"
+
+
 #include <QBuffer>
 #include <QClipboard>
 #include <QDir>
@@ -55,7 +60,6 @@
 #include <kpimutils/linklocator.h>
 #include <kpimutils/email.h>
 
-#include "articlewidget.h"
 #include "csshelper.h"
 #include "knarticle.h"
 #include "knarticlecollection.h"
@@ -73,6 +77,7 @@
 #include "knsourceviewwindow.h"
 #include "nntpjobs.h"
 #include "settings.h"
+
 #include "libkdepim/utils.h"
 
 using namespace KNode;
@@ -81,7 +86,7 @@ QList<ArticleWidget*> ArticleWidget::mInstances;
 
 ArticleWidget::ArticleWidget( QWidget *parent,
                               KXMLGUIClient *guiClient,
-                              KActionCollection *actionCollection ) :
+                              KActionCollection *actionCollection, bool isMainViewer ) :
   QWidget( parent ),
   mArticle( 0 ),
   mViewer( 0 ),
@@ -94,7 +99,8 @@ ArticleWidget::ArticleWidget( QWidget *parent,
   mOverrideCharset( KMime::Headers::Latin1 ),
   mTimer( 0 ),
   mGuiClient( guiClient ),
-  mActionCollection( actionCollection )
+  mActionCollection( actionCollection ),
+  mIsMainViewer( isMainViewer )
 {
   mInstances.append( this );
 
@@ -229,15 +235,15 @@ void ArticleWidget::initActions()
   mAttachmentStyleMenu->addAction( ra );
 
   mCharsetSelect = mActionCollection->add<KSelectAction>("set_charset");
-  mCharsetSelect->setText(i18n("Chars&et"));
+  mCharsetSelect->setText( i18n( "Set chars&et" ) );
   mCharsetSelect->setShortcutConfigurable( false );
-  QStringList cs = KGlobal::charsets()->descriptiveEncodingNames();
-  cs.prepend( i18n("Automatic") );
+  QStringList cs = Utilities::Locale::encodings();
+  cs.prepend( i18nc( "@item default character set", "Default") );
   mCharsetSelect->setItems( cs );
   mCharsetSelect->setCurrentItem( 0 );
   connect( mCharsetSelect, SIGNAL(triggered(const QString&)),SLOT(slotSetCharset(const QString&)) );
   mCharsetSelectKeyb = mActionCollection->addAction("set_charset_keyboard");
-  mCharsetSelectKeyb->setText(i18n("Charset"));
+  mCharsetSelectKeyb->setText( i18n( "Set charset" ) );
   connect(mCharsetSelectKeyb, SIGNAL(triggered(bool) ), SLOT(slotSetCharsetKeyboard()));
   mCharsetSelectKeyb->setShortcut(QKeySequence(Qt::Key_C));
 
@@ -357,8 +363,9 @@ void ArticleWidget::readConfig()
 void ArticleWidget::writeConfig()
 {
   // main viewer determines the settings
-  if ( knGlobals.artWidget != this )
+  if ( !mIsMainViewer ) {
     return;
+  }
 
   KConfigGroup conf(knGlobals.config(), "READNEWS" );
   conf.writeEntry( "attachmentStyle", mAttachmentStyle );
@@ -880,18 +887,18 @@ void ArticleWidget::displayAttachment( KMime::Content *att, int partNum )
   comment = toHtmlString( comment, ParseURL | FancyFormatting );
 
   QString href;
-  QString fileName = writeAttachmentToTempFile( att, partNum );
-  if ( fileName.isEmpty() ) {
+  KUrl file = writeAttachmentToTempFile( att, partNum );
+  if ( file.isEmpty() ) {
     href = "part://" + QString::number( partNum );
   } else {
-    href = "file:" + KUrl::toPercentEncoding( fileName );
-    mAttachementMap[fileName] = partNum;
+    href = file.url();
+    mAttachementMap[ file.path() ] = partNum;
   }
 
   if ( mAttachmentStyle == "inline" && inlinePossible( att ) ) {
     if ( ct->isImage() ) {
       html += "<div><a href=\"" + href + "\">"
-              "<img src=\"" + fileName + "\" border=\"0\"></a>"
+              "<img src=\"" + href + "\" border=\"0\"></a>"
               "</div><div><a href=\"" + href + "\">" + label + "</a>"
               "</div><div>" + comment + "</div><br>";
     } else { //text
@@ -1008,24 +1015,24 @@ void ArticleWidget::updateContents()
 
 
 
-QString ArticleWidget::writeAttachmentToTempFile( KMime::Content *att, int partNum )
+KUrl ArticleWidget::writeAttachmentToTempFile( KMime::Content *att, int partNum )
 {
   // more or less KMail code
   KTemporaryFile *tempFile = new KTemporaryFile();
   tempFile->setSuffix( '.' + QString::number( partNum ) );
   tempFile->open();
-  QString fname = tempFile->fileName();
+  KUrl file = KUrl( tempFile->fileName() );
   delete tempFile;
 
-  if( ::access( QFile::encodeName( fname ), W_OK ) != 0 )
+  if( ::access( QFile::encodeName( file.path() ), W_OK ) != 0 )
     // Not there or not writable
-    if( KDE_mkdir( QFile::encodeName( fname ), 0 ) != 0 ||
-        ::chmod( QFile::encodeName( fname ), S_IRWXU ) != 0 )
-      return QString(); //failed create
+    if( KDE_mkdir( QFile::encodeName( file.path() ), 0 ) != 0 ||
+        ::chmod( QFile::encodeName( file.path() ), S_IRWXU ) != 0 )
+      return KUrl(); //failed create
 
-  Q_ASSERT( !fname.isNull() );
+  Q_ASSERT( !file.fileName().isNull() );
 
-  mTempDirs.append( fname );
+  mTempDirs.append( file.path() );
   // strip off a leading path
   KMime::Headers::ContentType* ct = att->contentType();
   QString attName = ct->name();
@@ -1034,19 +1041,19 @@ QString ArticleWidget::writeAttachmentToTempFile( KMime::Content *att, int partN
     attName = attName.mid( slashPos + 1 );
   if( attName.isEmpty() )
     attName = "unnamed";
-  fname += '/' + attName;
+  file.addPath( attName );
 
   QByteArray data = att->decodedContent();
   // ### KMail does crlf2lf conversion here before writing the file
-  if( !KPIMUtils::kByteArrayToFile( data, fname, false, false, false ) )
-    return QString();
+  if( !KPIMUtils::kByteArrayToFile( data, file.toLocalFile(), false, false, false ) )
+    return KUrl();
 
-  mTempFiles.append( fname );
+  mTempFiles.append( file.toLocalFile() );
   // make file read-only so that nobody gets the impression that he might
   // edit attached files
-  ::chmod( QFile::encodeName( fname ), S_IRUSR );
+  ::chmod( QFile::encodeName( file.toLocalFile() ), S_IRUSR );
 
-  return fname;
+  return file;
 }
 
 
@@ -1406,7 +1413,7 @@ void ArticleWidget::slotSetCharset( const QString &charset )
   if ( charset.isEmpty() )
     return;
 
-  if ( charset == i18n("Automatic") ) {
+  if ( charset == i18nc( "@item default character set", "Default") ) {
     mForceCharset = false;
     mOverrideCharset = KMime::Headers::Latin1;
   } else {
