@@ -203,7 +203,7 @@ void KNArticleFactory::createReply(KNRemoteArticle *a, const QString &selectedTe
     if ( authorWantsMailCopies && !mailCopiesTo->mailboxes().isEmpty() ) {
       art->to()->clear();
       foreach ( const KMime::Types::Mailbox &mbox, mailCopiesTo->mailboxes() ) {
-        art->to()->addAddress(address);
+        art->to()->addAddress( mbox );
       }
     }
   }
@@ -550,10 +550,10 @@ void KNArticleFactory::sendMailExternal(const QString &address, const QString &s
     queries.append("body="+KUrl::toPercentEncoding(body));
 
   if (queries.count() > 0) {
-    query = "?";
+    query = '?';
     for ( QStringList::Iterator it = queries.begin(); it != queries.end(); ++it ) {
       if (it != queries.begin())
-        query.append("&");
+        query.append( '&' );
       query.append((*it));
     }
   }
@@ -739,7 +739,7 @@ void KNArticleFactory::processJob(KNJobData *j)
     if(art->collection()!=knGlobals.folderManager()->outbox())
       knGlobals.articleManager()->moveIntoFolder(lst, knGlobals.folderManager()->outbox());
 
-    KMessageBox::information(knGlobals.topWidget, i18n("You have aborted the posting of articles. The unsent articles are stored in the \"Outbox\" folder."));
+    KMessageBox::information(knGlobals.topWidget, i18n("You canceled the article posting. The unsent articles are stored in the \"Outbox\" folder."));
 
     return;
   }
