@@ -12,37 +12,10 @@
     Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
 */
 
-
-#include <QPainter>
-
-#include <QLabel>
-//Added by qt3to4:
-#include <QGridLayout>
-#include <QBoxLayout>
-#include <QVBoxLayout>
-#include <QTextEdit>
-
-#include <kcharsets.h>
-#include <klocale.h>
-#include <knumvalidator.h>
-#include <kmessagebox.h>
-#include <kmimetypetrader.h>
-#include <kcolordialog.h>
-#include <kfontdialog.h>
-#include <kfiledialog.h>
-#include <kscoringeditor.h>
-#include <sonnet/configwidget.h>
-#include <kcombobox.h>
-#include <libkpgp/kpgpui.h>
-#include <kurlcompletion.h>
-#include <kiconloader.h>
-#include <kpushbutton.h>
-#include <kvbox.h>
-#include <krun.h>
+#include "knconfigwidgets.h"
 
 #include "knaccountmanager.h"
 #include "knconfig.h"
-#include "knconfigwidgets.h"
 #include "knconfigmanager.h"
 #include "kndisplayedheader.h"
 #include "kngroupmanager.h"
@@ -56,6 +29,37 @@
 #include "ui_readnewsnavigationwidget_base.h"
 #include "ui_readnewsviewerwidget_base.h"
 #include "settings.h"
+#include "utils/locale.h"
+
+
+#include <QPainter>
+#include <QLabel>
+#include <QGridLayout>
+#include <QBoxLayout>
+#include <QVBoxLayout>
+#include <QTextEdit>
+
+#include <kcharsets.h>
+#include <kio/ioslave_defaults.h>
+#include <klocale.h>
+#include <knumvalidator.h>
+#include <kmessagebox.h>
+#include <kmimetypetrader.h>
+#include <kmime/kmime_dateformatter.h>
+#include <kcolordialog.h>
+#include <kfontdialog.h>
+#include <kfiledialog.h>
+#include <kscoringeditor.h>
+#include <sonnet/configwidget.h>
+#include <kcombobox.h>
+#include <libkpgp/kpgpui.h>
+#include <kurlcompletion.h>
+#include <kiconloader.h>
+#include <kpushbutton.h>
+#include <kvbox.h>
+#include <krun.h>
+
+
 
 KNode::IdentityWidget::IdentityWidget( Identity *d, const KComponentData &inst, QWidget *parent ) :
   KCModule( inst ,parent ),
@@ -68,7 +72,7 @@ KNode::IdentityWidget::IdentityWidget( Identity *d, const KComponentData &inst,
   topL->setMargin(5);
 
   n_ame=new KLineEdit(this);
-  QLabel *l=new QLabel(i18n("&Name:"),this);
+  QLabel *l = new QLabel( i18nc( "@label:textbox Name of the user in a message", "&Name:" ), this );
   l->setBuddy(n_ame);
   topL->addWidget(l, 0,0);
   topL->addWidget(n_ame, 0, 1, 1,2);
@@ -120,7 +124,7 @@ KNode::IdentityWidget::IdentityWidget( Identity *d, const KComponentData &inst,
   connect( m_ailCopiesTo, SIGNAL(textChanged(const QString&)), SLOT(changed()) );
 
   s_igningKey = new Kpgp::SecretKeyRequester(this);
-  s_igningKey->dialogButton()->setText(i18n("Chan&ge..."));
+  s_igningKey->dialogButton()->setText( i18nc( "@action:button Change signing key", "Chan&ge..." ) );
   s_igningKey->setDialogCaption(i18n("Your OpenPGP Key"));
   s_igningKey->setDialogMessage(i18n("Select the OpenPGP key which should be "
       "used for signing articles."));
@@ -157,11 +161,11 @@ KNode::IdentityWidget::IdentityWidget( Identity *d, const KComponentData &inst,
   f_ileName->setWhatsThis( msg );
   s_ig->setWhatsThis( msg );
 
-  c_hooseBtn = new QPushButton( i18n("Choo&se..."), this);
+  c_hooseBtn = new QPushButton( i18nc( "@action:button Choose a file that contains a signature for messages", "Choo&se..." ), this );
   connect(c_hooseBtn, SIGNAL(clicked()),
           this, SLOT(slotSignatureChoose()));
   topL->addWidget(c_hooseBtn, 7, 2 );
-  e_ditBtn = new QPushButton( i18n("&Edit File"), this);
+  e_ditBtn = new QPushButton( i18nc("@action:button Launch the edit of the signature file", "&Edit File" ), this );
   connect(e_ditBtn, SIGNAL(clicked()),
           this, SLOT(slotSignatureEdit()));
   topL->addWidget(e_ditBtn, 8, 2);
@@ -183,7 +187,7 @@ KNode::IdentityWidget::IdentityWidget( Identity *d, const KComponentData &inst,
 
   topL->setColumnStretch(1,1);
   topL->setRowStretch(7,1);
-  topL->setResizeMode(QLayout::SetMinimumSize);
+  topL->setSizeConstraint( QLayout::SetMinimumSize );
   connect(s_ig,SIGNAL(textChanged ( const QString & )),
           this,SLOT(textFileNameChanged(const QString &)));
 
@@ -299,7 +303,7 @@ KNode::NntpAccountListWidget::NntpAccountListWidget( const KComponentData &inst,
   setupUi( this );
 
   // account listbox
-  connect( mAccountList, SIGNAL( itemActivated( QListWidgetItem* ) ), SLOT( slotEditBtnClicked() ) );
+  connect( mAccountList, SIGNAL( itemDoubleClicked( QListWidgetItem* ) ), SLOT( slotEditBtnClicked() ) );
   connect( mAccountList, SIGNAL( itemSelectionChanged() ), SLOT( slotSelectionChanged() ) );
 
   // buttons
@@ -485,9 +489,17 @@ KNode::NntpAccountConfDialog::NntpAccountConfDialog( KNNntpAccount *a, QWidget *
       mEncTLS->setChecked( true );
       break;
   }
+  connect( mEncNone, SIGNAL( toggled( bool ) ),
+           this, SLOT( encryptionChanged( bool ) ) );
+  connect( mEncSSL, SIGNAL( toggled( bool ) ),
+           this, SLOT( encryptionChanged( bool ) ) );
+  connect( mEncTLS, SIGNAL( toggled( bool ) ),
+           this, SLOT( encryptionChanged( bool ) ) );
+
 
   mIntervalChecking->setChecked( a->intervalChecking() );
   mInterval->setValue( a->checkInterval() );
+  mInterval->setSuffix(ki18np(" minute", " minutes"));
 
   // identity tab
   mIdentityWidget = new KNode::IdentityWidget( a->identity(), knGlobals.componentData(), this );
@@ -511,7 +523,7 @@ KNode::NntpAccountConfDialog::~NntpAccountConfDialog()
 
 void KNode::NntpAccountConfDialog::slotServerTextEdited()
 {
-  if ( mName->text().trimmed() == "" ) {
+  if ( mName->text().trimmed().isEmpty() ) {
     mUseServerForName = true;
   }
 
@@ -570,6 +582,19 @@ void KNode::NntpAccountConfDialog::slotPasswordChanged()
     mPassword->setText( mAccount->pass() );
 }
 
+
+void KNode::NntpAccountConfDialog::encryptionChanged( bool checked )
+{
+  if ( checked ) { // All 3 buttons are connected to this slot, so only the checked one is taken into account.
+    if ( mEncNone->isChecked() ) {
+      mPort->setValue( DEFAULT_NNTP_PORT );
+    } else if ( mEncSSL->isChecked() || mEncTLS->isChecked() ) {
+      mPort->setValue( DEFAULT_NNTPS_PORT );
+    }
+  }
+}
+
+
 //END: NNTP account configuration widgets ------------------------------------
 
 //===================================================================================
@@ -635,7 +660,7 @@ KNode::AppearanceWidget::AppearanceWidget( const KComponentData &inst, QWidget *
   topL->addWidget( c_olorCB, 0, 0, 1, 3 );
   connect(c_olorCB, SIGNAL(toggled(bool)), this, SLOT(slotColCheckBoxToggled(bool)));
 
-  c_olChngBtn=new QPushButton(i18n("Cha&nge..."), this);
+  c_olChngBtn = new QPushButton( i18nc( "@action:button Run a color selection dialog", "Cha&nge..." ), this );
   connect(c_olChngBtn, SIGNAL(clicked()), this, SLOT(slotColChangeBtnClicked()));
   topL->addWidget( c_olChngBtn, 1, 2, 1, 1 );
 
@@ -650,7 +675,7 @@ KNode::AppearanceWidget::AppearanceWidget( const KComponentData &inst, QWidget *
   topL->addWidget(f_ontCB , 4, 0, 1, 3 );
   connect(f_ontCB, SIGNAL(toggled(bool)), this, SLOT(slotFontCheckBoxToggled(bool)));
 
-  f_ntChngBtn=new QPushButton(i18n("Chang&e..."), this);
+  f_ntChngBtn = new QPushButton( i18nc( "@action:button Run a font selection dialog", "Chang&e..."), this);
   connect(f_ntChngBtn, SIGNAL(clicked()), this, SLOT(slotFontChangeBtnClicked()));
   topL->addWidget( f_ntChngBtn, 5, 2, 1, 1 );
 
@@ -830,23 +855,26 @@ void KNode::ReadNewsGeneralWidget::load()
 {
   KCModule::load();
   switch ( knGlobals.settings()->dateFormat() ) {
-    case KNode::Settings::EnumDateFormat::CTime: mStandardDateFormat->setChecked( true ); break;
-    case KNode::Settings::EnumDateFormat::Localized: mLocalizedDateFormat->setChecked( true ); break;
-    case KNode::Settings::EnumDateFormat::Fancy: mFancyDateFormat->setChecked( true ); break;
-    case KNode::Settings::EnumDateFormat::Custom: mCustomDateFormat->setChecked( true ); break;
+    case KMime::DateFormatter::CTime: mStandardDateFormat->setChecked( true ); break;
+    case KMime::DateFormatter::Localized: mLocalizedDateFormat->setChecked( true ); break;
+    case KMime::DateFormatter::Fancy: mFancyDateFormat->setChecked( true ); break;
+    case KMime::DateFormatter::Custom: mCustomDateFormat->setChecked( true ); break;
+    case KMime::DateFormatter::Iso: break; // not used
+    case KMime::DateFormatter::Rfc: break; // not used
+
   }
 }
 
 void KNode::ReadNewsGeneralWidget::save()
 {
   if ( mStandardDateFormat->isChecked() )
-    knGlobals.settings()->setDateFormat( KNode::Settings::EnumDateFormat::CTime );
+    knGlobals.settings()->setDateFormat( KMime::DateFormatter::CTime );
   if ( mLocalizedDateFormat->isChecked() )
-    knGlobals.settings()->setDateFormat( KNode::Settings::EnumDateFormat::Localized );
+    knGlobals.settings()->setDateFormat( KMime::DateFormatter::Localized );
   if ( mFancyDateFormat->isChecked() )
-    knGlobals.settings()->setDateFormat( KNode::Settings::EnumDateFormat::Fancy );
+    knGlobals.settings()->setDateFormat( KMime::DateFormatter::Fancy );
   if ( mCustomDateFormat->isChecked() )
-    knGlobals.settings()->setDateFormat( KNode::Settings::EnumDateFormat::Custom );
+    knGlobals.settings()->setDateFormat( KMime::DateFormatter::Custom );
   KCModule::save();
 }
 
@@ -895,11 +923,11 @@ KNode::DisplayedHeadersWidget::DisplayedHeadersWidget( DisplayedHeaders *d, cons
   topL->addWidget( mHeaderList, 0, 0, 7, 1);
 
   // buttons
-  a_ddBtn=new QPushButton(i18n("&Add..."), this);
+  a_ddBtn = new QPushButton( i18nc( "@action:button Add a new message header field (open dialog)", "&Add..." ), this );
   connect(a_ddBtn, SIGNAL(clicked()), this, SLOT(slotAddBtnClicked()));
   topL->addWidget(a_ddBtn, 0,1);
 
-  d_elBtn=new QPushButton(i18n("&Delete"), this);
+  d_elBtn = new QPushButton( i18nc( "@action:button Delete a message header field", "&Delete" ), this);
   connect(d_elBtn, SIGNAL(clicked()), this, SLOT(slotDelBtnClicked()));
   topL->addWidget(d_elBtn, 1,1);
 
@@ -907,11 +935,11 @@ KNode::DisplayedHeadersWidget::DisplayedHeadersWidget( DisplayedHeaders *d, cons
   connect(e_ditBtn, SIGNAL(clicked()), this, SLOT(slotEditBtnClicked()));
   topL->addWidget(e_ditBtn, 2,1);
 
-  u_pBtn=new QPushButton(i18n("&Up"), this);
+  u_pBtn = new QPushButton( i18nc( "@action:button Move an element of a list up", "&Up" ), this );
   connect(u_pBtn, SIGNAL(clicked()), this, SLOT(slotUpBtnClicked()));
   topL->addWidget(u_pBtn, 4,1);
 
-  d_ownBtn=new QPushButton(i18n("Do&wn"), this);
+  d_ownBtn = new QPushButton( i18nc( "@action:button Move an element of a list down", "Do&wn" ), this );
   connect(d_ownBtn, SIGNAL(clicked()), this, SLOT(slotDownBtnClicked()));
   topL->addWidget(d_ownBtn, 5,1);
 
@@ -950,8 +978,9 @@ KNode::DisplayedHeadersWidget::HdrItem* KNode::DisplayedHeadersWidget::generateI
   if(h->hasName()) {
     text=h->translatedName();
     text+=": <";
-  } else
-    text="<";
+  } else {
+    text = '<';
+  }
   text+=h->header();
   text+='>';
   return new HdrItem(text,h);
@@ -1078,7 +1107,7 @@ KNode::DisplayedHeaderConfDialog::DisplayedHeaderConfDialog( KNDisplayedHeader *
   h_drC=new KComboBox(true, nameW);
   h_drC->lineEdit()->setMaxLength(64);
   connect(h_drC, SIGNAL(activated(int)), this, SLOT(slotActivated(int)));
-  QLabel *label=new QLabel(i18n("H&eader:"),nameW);
+  QLabel *label = new QLabel( i18nc( "@label:textbox Edition of a message header name", "H&eader:" ), nameW );
   label->setBuddy(h_drC);
   nameL->addWidget(label,0,0);
   nameL->addWidget(h_drC,0,1);
@@ -1086,7 +1115,7 @@ KNode::DisplayedHeaderConfDialog::DisplayedHeaderConfDialog( KNDisplayedHeader *
   n_ameE=new KLineEdit(nameW);
 
   n_ameE->setMaxLength(64);
-  label=new QLabel(i18n("Displayed na&me:"),nameW);
+  label = new QLabel( i18nc( "@label:textbox Edition of the displayed name in the UI of a message header", "Displayed na&me:" ), nameW );
   label->setBuddy(n_ameE);
   nameL->addWidget(label,1,0);
   nameL->addWidget(n_ameE,1,1);
@@ -1094,18 +1123,20 @@ KNode::DisplayedHeaderConfDialog::DisplayedHeaderConfDialog( KNDisplayedHeader *
 
   topL->addWidget(nameW,0,0, 1, 2 );
 
-  QGroupBox *ngb=new QGroupBox(i18n("Name"), page);
+  QGroupBox *ngb = new QGroupBox(i18n("Name"), page);
   // ### hide style settings for now, the new viewer doesn't support this yet
   ngb->hide();
   QVBoxLayout *ngbL = new QVBoxLayout(ngb);
   ngbL->setSpacing(5);
   ngbL->setMargin(8);
-  ngbL->setAutoAdd(true);
   ngbL->addSpacing(fontMetrics().lineSpacing()-4);
   n_ameCB[0]=new QCheckBox(i18n("&Large"), ngb);
   n_ameCB[1]=new QCheckBox(i18n("&Bold"), ngb);
   n_ameCB[2]=new QCheckBox(i18n("&Italic"), ngb);
   n_ameCB[3]=new QCheckBox(i18n("&Underlined"), ngb);
+  for( int i = 0 ; i < 4 ; ++i) {
+    ngbL->addWidget( n_ameCB[i] );
+  }
   topL->addWidget(ngb,1,0);
 
   QGroupBox *vgb=new QGroupBox(i18n("Value"), page);
@@ -1114,12 +1145,14 @@ KNode::DisplayedHeaderConfDialog::DisplayedHeaderConfDialog( KNDisplayedHeader *
   QVBoxLayout *vgbL = new QVBoxLayout(vgb);
   vgbL->setSpacing(5);
   vgbL->setMargin(8);
-  vgbL->setAutoAdd(true);
   vgbL->addSpacing(fontMetrics().lineSpacing()-4);
   v_alueCB[0]=new QCheckBox(i18n("L&arge"), vgb);
   v_alueCB[1]=new QCheckBox(i18n("Bol&d"), vgb);
   v_alueCB[2]=new QCheckBox(i18n("I&talic"), vgb);
   v_alueCB[3]=new QCheckBox(i18n("U&nderlined"), vgb);
+  for( int i = 0 ; i < 4 ; ++i) {
+    vgbL->addWidget( v_alueCB[i] );
+  }
   topL->addWidget(vgb,1,1);
 
   topL->setColumnStretch(0,1);
@@ -1229,7 +1262,7 @@ KNode::FilterListWidget::FilterListWidget( const KComponentData &inst, QWidget *
   // == Filters =================================================
 
   mFilterList = new QListWidget( this );
-  QLabel *label=new QLabel(i18n("&Filters:"), this );
+  QLabel *label = new QLabel( i18nc("@title", "&Filters:" ), this );
   label->setBuddy(mFilterList);
   topL->addWidget( label, 0, 0 );
 
@@ -1237,7 +1270,7 @@ KNode::FilterListWidget::FilterListWidget( const KComponentData &inst, QWidget *
   connect( mFilterList, SIGNAL( itemActivated( QListWidgetItem* ) ), SLOT( slotEditBtnClicked() ) );
   topL->addWidget( mFilterList, 1, 0, 5, 1);
 
-  a_ddBtn=new QPushButton(i18n("&Add..."), this);
+  a_ddBtn = new QPushButton( i18nc("@action:button Add a new filter", "&Add..." ), this );
   connect(a_ddBtn, SIGNAL(clicked()), this, SLOT(slotAddBtnClicked()));
   topL->addWidget(a_ddBtn,1,1);
 
@@ -1245,37 +1278,37 @@ KNode::FilterListWidget::FilterListWidget( const KComponentData &inst, QWidget *
   connect(e_ditBtn, SIGNAL(clicked()), this, SLOT(slotEditBtnClicked()));
   topL->addWidget(e_ditBtn,2,1);
 
-  c_opyBtn=new QPushButton(i18n("Co&py..."), this);
+  c_opyBtn = new QPushButton( i18nc( "@action:button Copy a filter", "Co&py..."), this);
   connect(c_opyBtn, SIGNAL(clicked()), this, SLOT(slotCopyBtnClicked()));
   topL->addWidget(c_opyBtn,3,1);
 
-  d_elBtn=new QPushButton(i18n("&Delete"), this);
+  d_elBtn = new QPushButton( i18nc( "@action:button Delete a filter", "&Delete"), this);
   connect(d_elBtn, SIGNAL(clicked()), this, SLOT(slotDelBtnClicked()));
   topL->addWidget(d_elBtn,4,1);
 
   // == Menu ====================================================
 
   mMenuList = new QListWidget( this );
-  label=new QLabel( i18n("&Menu:"), this );
+  label = new QLabel( i18nc( "@title", "&Menu:"), this );
   label->setBuddy(mMenuList);
   topL->addWidget( label, 6, 0 );
 
   connect( mMenuList, SIGNAL( itemSelectionChanged() ), SLOT( slotSelectionChangedMenu() ) );
   topL->addWidget( mMenuList, 7, 0, 5, 1);
 
-  u_pBtn=new QPushButton(i18n("&Up"), this);
+  u_pBtn = new QPushButton( i18nc( "@action:button move something up in a list", "&Up"), this );
   connect(u_pBtn, SIGNAL(clicked()), this, SLOT(slotUpBtnClicked()));
   topL->addWidget(u_pBtn,7,1);
 
-  d_ownBtn=new QPushButton(i18n("Do&wn"), this);
+  d_ownBtn = new QPushButton( i18nc( "@action:button move something down in a list", "Do&wn"), this );
   connect(d_ownBtn, SIGNAL(clicked()), this, SLOT(slotDownBtnClicked()));
   topL->addWidget(d_ownBtn,8,1);
 
-  s_epAddBtn=new QPushButton(i18n("Add\n&Separator"), this);
+  s_epAddBtn = new QPushButton( i18nc( "@action:button", "Add\n&Separator" ), this );
   connect(s_epAddBtn, SIGNAL(clicked()), this, SLOT(slotSepAddBtnClicked()));
   topL->addWidget(s_epAddBtn,9,1);
 
-  s_epRemBtn=new QPushButton(i18n("&Remove\nSeparator"), this);
+  s_epRemBtn = new QPushButton( i18nc( "@action:button", "&Remove\nSeparator" ), this );
   connect(s_epRemBtn, SIGNAL(clicked()), this, SLOT(slotSepRemBtnClicked()));
   topL->addWidget(s_epRemBtn,10,1);
 
@@ -1496,7 +1529,7 @@ KNode::PostNewsTechnicalWidget::PostNewsTechnicalWidget( const KComponentData &i
 {
   setupUi( this );
 
-  mCharset->addItems( KGlobal::charsets()->availableEncodingNames() );
+  mCharset->addItems( KNode::Utilities::Locale::encodings() );
   mEncoding->addItem( i18n("Allow 8-bit") );
   mEncoding->addItem( i18n("7-bit (Quoted-Printable)") );
 
@@ -1518,8 +1551,8 @@ void KNode::PostNewsTechnicalWidget::load()
 {
   KCModule::load();
 
-  kDebug(5003) << knGlobals.settings()->charset();
-  mCharset->setCurrentIndex( mCharset->findText( knGlobals.settings()->charset() ) );
+  QString charsetDesc = KGlobal::charsets()->descriptionForEncoding( knGlobals.settings()->charset() );
+  mCharset->setCurrentIndex( mCharset->findText( charsetDesc ) );
   mEncoding->setCurrentIndex( knGlobals.settings()->allow8BitBody() ? 0 : 1 );
 
   mHeaderList->clear();
@@ -1531,7 +1564,8 @@ void KNode::PostNewsTechnicalWidget::load()
 
 void KNode::PostNewsTechnicalWidget::save()
 {
-  knGlobals.settings()->setCharset( mCharset->currentText() );
+  QString charset = KGlobal::charsets()->encodingForName( mCharset->currentText() );
+  knGlobals.settings()->setCharset( charset );
   knGlobals.settings()->setAllow8BitBody( mEncoding->currentIndex() == 0 );
 
   XHeader::List list;
@@ -1736,30 +1770,30 @@ KNode::GroupCleanupWidget::GroupCleanupWidget( Cleanup *data, QWidget *parent )
   connect( mExpEnabled, SIGNAL(toggled(bool)), SIGNAL(changed()) );
 
   mExpDays = new KIntSpinBox( 0, 99999, 1, 0, mExpGroup );
+  mExpDays->setSuffix(ki18np(" day", " days"));
   QLabel *label = new QLabel( i18n("&Purge groups every:"), mExpGroup );
   label->setBuddy( mExpDays );
   grid->addWidget( label, 2, 0 );
   grid->addWidget( mExpDays, 2, 1, Qt::AlignRight );
   connect( mExpDays, SIGNAL(valueChanged(int)), SIGNAL(changed()) );
-  connect( mExpDays, SIGNAL(valueChanged(int)), SLOT(expDaysChanged(int)) );
   connect( mExpEnabled, SIGNAL(toggled(bool)), label, SLOT(setEnabled(bool)) );
   connect( mExpEnabled, SIGNAL(toggled(bool)), mExpDays, SLOT(setEnabled(bool)) );
 
   mExpReadDays = new KIntSpinBox( 0, 99999, 1, 0, mExpGroup );
+  mExpReadDays->setSuffix(ki18np(" day", " days"));
   label = new QLabel( i18n("&Keep read articles:"), mExpGroup );
   label->setBuddy( mExpReadDays );
   grid->addWidget( label, 3, 0 );
   grid->addWidget( mExpReadDays, 3, 1, Qt::AlignRight );
   connect( mExpReadDays, SIGNAL(valueChanged(int)), SIGNAL(changed()) );
-  connect( mExpReadDays, SIGNAL(valueChanged(int)), SLOT(expReadDaysChanged(int)) );
 
   mExpUnreadDays = new KIntSpinBox( 0, 99999, 1, 0, mExpGroup );
+  mExpUnreadDays->setSuffix(ki18np(" day", " days"));
   label = new QLabel( i18n("Keep u&nread articles:"), mExpGroup );
   label->setBuddy( mExpUnreadDays );
   grid->addWidget( label, 4, 0 );
   grid->addWidget( mExpUnreadDays, 4, 1, Qt::AlignRight );
   connect( mExpUnreadDays, SIGNAL(valueChanged(int)), SIGNAL(changed()) );
-  connect( mExpUnreadDays, SIGNAL(valueChanged(int)), SLOT(expUnreadDaysChanged(int)) );
 
   mExpUnavailable = new QCheckBox( i18n("&Remove articles that are not available on the server"), mExpGroup );
   grid->addWidget( mExpUnavailable, 5, 0, 1, 2 );
@@ -1808,22 +1842,6 @@ void KNode::GroupCleanupWidget::slotDefaultToggled( bool state )
 }
 
 
-void KNode::GroupCleanupWidget::expDaysChanged(int value)
-{
-  mExpDays->setSuffix( i18np(" day", " days", value) );
-}
-
-void KNode::GroupCleanupWidget::expReadDaysChanged(int value)
-{
-  mExpReadDays->setSuffix( i18np(" day", " days", value) );
-}
-
-void KNode::GroupCleanupWidget::expUnreadDaysChanged(int value)
-{
-  mExpUnreadDays->setSuffix( i18np(" day", " days", value) );
-}
-
-
 KNode::CleanupWidget::CleanupWidget( const KComponentData &inst,QWidget *parent ) :
   KCModule(inst, parent ),
   d_ata( knGlobals.configManager()->cleanup() )
@@ -1850,12 +1868,12 @@ KNode::CleanupWidget::CleanupWidget( const KComponentData &inst,QWidget *parent
   foldersL->addWidget(f_olderCB,1,0, 1, 2 );
 
   f_olderDays=new KIntSpinBox( 0, 99999, 1, 0, foldersB );
+  f_olderDays->setSuffix(ki18np(" day", " days"));
   f_olderDaysL=new QLabel(i18n("P&urge folders every:"),foldersB);
   f_olderDaysL->setBuddy(f_olderDays);
   foldersL->addWidget(f_olderDaysL,2,0);
   foldersL->addWidget(f_olderDays,2,1,Qt::AlignRight);
   connect(f_olderDays, SIGNAL(valueChanged(int)), SLOT(changed()));
-  connect(f_olderDays, SIGNAL(valueChanged(int)), SLOT(slotFolderDaysChanged(int)));
 
   foldersL->setColumnStretch(1,1);
 
@@ -1897,11 +1915,6 @@ void KNode::CleanupWidget::slotFolderCBtoggled(bool b)
   emit changed(true);
 }
 
-void KNode::CleanupWidget::slotFolderDaysChanged(int value)
-{
-  f_olderDays->setSuffix(i18np(" day", " days", value));
-}
-
 //END: Cleanup configuration widgets -----------------------------------------
 
 //------------------------
