@@ -32,6 +32,7 @@
 #include "korganizer/baseview.h"
 
 #include <KCal/CalendarLocal>
+#include <KCal/IncidenceFormatter>
 
 #include <KLocale>
 #include <KMessageBox>
@@ -64,7 +65,7 @@ void KOJournalEditor::init()
 void KOJournalEditor::reload()
 {
   if ( mJournal ) {
-    readJournal( mJournal, true );
+    readJournal( mJournal, QDate(), true );
   }
 }
 
@@ -89,7 +90,7 @@ void KOJournalEditor::setupGeneral()
   mGeneral->finishSetup();
 }
 
-void KOJournalEditor::editIncidence( Incidence *incidence, Calendar *calendar )
+void KOJournalEditor::editIncidence( Incidence *incidence, const QDate &date, Calendar *calendar )
 {
   Journal *journal = dynamic_cast<Journal*>( incidence );
   if ( journal ) {
@@ -97,11 +98,12 @@ void KOJournalEditor::editIncidence( Incidence *incidence, Calendar *calendar )
 
     mJournal = journal;
     mCalendar = calendar;
-    readJournal( mJournal, false );
+    readJournal( mJournal, date, false );
   }
 
   setCaption( i18nc( "@title:window",
-                     "Edit Journal: %1", KOHelper::resourceLabel( calendar, incidence ) ) );
+                     "Edit Journal: %1",
+                     IncidenceFormatter::resourceString( calendar, incidence ) ) );
 
 }
 
@@ -150,12 +152,11 @@ bool KOJournalEditor::processInput()
       // Don't do anything
     } else {
       fillJournal( mJournal );
-      mChanger->changeIncidence( oldJournal, mJournal );
+      rc = mChanger->changeIncidence( oldJournal, mJournal, KOGlobals::NOTHING_MODIFIED, this );
     }
     delete journal;
     delete oldJournal;
     return rc;
-
   } else {
     mJournal = new Journal;
     mJournal->setOrganizer( Person( KOPrefs::instance()->fullName(),
@@ -214,13 +215,13 @@ bool KOJournalEditor::incidenceModified()
   return modified;
 }
 
-void KOJournalEditor::readJournal( Journal *journal, bool tmpl )
+void KOJournalEditor::readJournal( Journal *journal, const QDate & date, bool tmpl )
 {
   if ( !journal ) {
     return;
   }
 
-  mGeneral->readJournal( journal, tmpl );
+  mGeneral->readJournal( journal, date, tmpl );
   mDetails->readIncidence( journal );
 }
 
@@ -241,19 +242,8 @@ bool KOJournalEditor::validateInput()
   return true;
 }
 
-int KOJournalEditor::msgItemDelete()
+void KOJournalEditor::modified()
 {
-  return KMessageBox::warningContinueCancel(
-    this,
-    i18nc( "@info", "This journal entry will be permanently deleted." ),
-    i18nc( "@title:window", "KOrganizer Confirmation" ),
-    KStandardGuiItem::del() );
-}
-
-void KOJournalEditor::modified( int modification )
-{
-  Q_UNUSED( modification );
-
   // Play dumb, just reload the Journal. This dialog has become so complicated
   // that there is no point in trying to be smart here...
   reload();
@@ -265,7 +255,7 @@ void KOJournalEditor::loadTemplate( CalendarLocal &cal )
   if ( journals.count() == 0 ) {
     KMessageBox::error( this, i18nc( "@info", "Template does not contain a valid journal." ) );
   } else {
-    readJournal( journals.first(), true );
+    readJournal( journals.first(), QDate(), true );
   }
 }
 
