@@ -24,26 +24,14 @@
 #ifndef NAVIGATORBAR_H
 #define NAVIGATORBAR_H
 
-#include <kcal/incidencebase.h>
+#include <KCal/IncidenceBase>
+using namespace KCal;
 
-#include <QLabel>
-#include <QMouseEvent>
+#include <QDate>
+#include <QWidget>
 
 class QToolButton;
 
-class ActiveLabel : public QLabel
-{
-  Q_OBJECT
-  public:
-    explicit ActiveLabel( QWidget *parent );
-
-  signals:
-    void clicked();
-
-  protected:
-    void mouseReleaseEvent ( QMouseEvent *e );
-};
-
 class NavigatorBar: public QWidget
 {
   Q_OBJECT
@@ -70,18 +58,16 @@ class NavigatorBar: public QWidget
                                          const QString &whatsThis );
 
   private slots:
-    void selectMonth();
-    void selectYear();
+    void selectMonthFromMenu();
+    void selectYearFromMenu();
 
   private:
-    bool mHasMinWidth;
-
     QDate mDate;
 
     QToolButton *mPrevYear;
     QToolButton *mPrevMonth;
-    ActiveLabel *mMonth;
-    ActiveLabel *mYear;
+    QToolButton *mMonth;
+    QToolButton *mYear;
     QToolButton *mNextMonth;
     QToolButton *mNextYear;
 };
