@@ -19,26 +19,58 @@
   Boston, MA 02110-1301, USA.
 */
 
-#include <qdatetime.h>
-#include <qpopupmenu.h>
-
-#include <klocale.h>
-
 #include "kdatepickerpopup.h"
 
-KDatePickerPopup::KDatePickerPopup( int items, const QDate &date, QWidget *parent,
-                                    const char *name )
-  : QPopupMenu( parent, name )
+#include <KDatePicker>
+#include <KLocale>
+
+#include <QtCore/QDateTime>
+#include <QtGui/QWidgetAction>
+
+using namespace KPIM;
+
+class KDatePickerAction : public QWidgetAction
+{
+  public:
+    KDatePickerAction( KDatePicker *widget, QObject *parent )
+      : QWidgetAction( parent ),
+        mDatePicker( widget ), mOriginalParent( widget->parentWidget() )
+    {
+    }
+
+  protected:
+    QWidget *createWidget( QWidget *parent )
+    {
+      mDatePicker->setParent( parent );
+      return mDatePicker;
+    }
+
+    void deleteWidget( QWidget *widget )
+    {
+      if ( widget != mDatePicker ) {
+        return;
+      }
+
+      mDatePicker->setParent( mOriginalParent );
+    }
+
+  private:
+    KDatePicker *mDatePicker;
+    QWidget *mOriginalParent;
+};
+
+KDatePickerPopup::KDatePickerPopup( Items items, const QDate &date, QWidget *parent )
+  : QMenu( parent )
 {
   mItems = items;
 
   mDatePicker = new KDatePicker( this );
   mDatePicker->setCloseButton( false );
 
-  connect( mDatePicker, SIGNAL( dateEntered( QDate ) ),
-           SLOT( slotDateChanged( QDate ) ) );
-  connect( mDatePicker, SIGNAL( dateSelected( QDate ) ),
-           SLOT( slotDateChanged( QDate ) ) );
+  connect( mDatePicker, SIGNAL( dateEntered( const QDate& ) ),
+           SLOT( slotDateChanged( const QDate& ) ) );
+  connect( mDatePicker, SIGNAL( dateSelected( const QDate& ) ),
+           SLOT( slotDateChanged( const QDate& ) ) );
 
   mDatePicker->setDate( date );
 
@@ -47,28 +79,33 @@ KDatePickerPopup::KDatePickerPopup( int items, const QDate &date, QWidget *paren
 
 void KDatePickerPopup::buildMenu()
 {
-  if ( isVisible() ) return;
+  if ( isVisible() ) {
+    return;
+  }
   clear();
 
   if ( mItems & DatePicker ) {
-    insertItem( mDatePicker );
+    addAction( new KDatePickerAction( mDatePicker, this ) );
 
-    if ( ( mItems & NoDate ) || ( mItems & Words ) )
-      insertSeparator();
+    if ( ( mItems & NoDate ) || ( mItems & Words ) ) {
+      addSeparator();
+    }
   }
 
   if ( mItems & Words ) {
-    insertItem( i18n("&Today"), this, SLOT( slotToday() ) );
-    insertItem( i18n("To&morrow"), this, SLOT( slotTomorrow() ) );
-    insertItem( i18n("Next &Week"), this, SLOT( slotNextWeek() ) );
-    insertItem( i18n("Next M&onth"), this, SLOT( slotNextMonth() ) );
+    addAction( i18nc( "@option today", "&Today" ), this, SLOT( slotToday() ) );
+    addAction( i18nc( "@option tomorrow", "To&morrow" ), this, SLOT( slotTomorrow() ) );
+    addAction( i18nc( "@option next week", "Next &Week" ), this, SLOT( slotNextWeek() ) );
+    addAction( i18nc( "@option next month", "Next M&onth" ), this, SLOT( slotNextMonth() ) );
 
-    if ( mItems & NoDate )
-      insertSeparator();
+    if ( mItems & NoDate ) {
+      addSeparator();
+    }
   }
 
-  if ( mItems & NoDate )
-    insertItem( i18n("No Date"), this, SLOT( slotNoDate() ) );
+  if ( mItems & NoDate ) {
+    addAction( i18nc( "@option do not specify a date", "No Date" ), this, SLOT( slotNoDate() ) );
+  }
 }
 
 KDatePicker *KDatePickerPopup::datePicker() const
@@ -89,7 +126,7 @@ void KDatePickerPopup::setItems( int items )
 }
 #endif
 
-void KDatePickerPopup::slotDateChanged( QDate date )
+void KDatePickerPopup::slotDateChanged( const QDate &date )
 {
   emit dateChanged( date );
   hide();
