@@ -19,10 +19,11 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef __KPIM_SHARED_PLUGINLOADER_H__
-#define __KPIM_SHARED_PLUGINLOADER_H__
+#ifndef KDEPIM_PLUGINLOADER_H
+#define KDEPIM_PLUGINLOADER_H
 
-#include <pluginloaderbase.h>
+#include "pluginloaderbase.h"
+#include <KLibrary>
 
 namespace KPIM {
 
@@ -76,7 +77,7 @@ namespace KPIM {
    *
    **/
   template< typename T, typename T_config >
-  class KDE_EXPORT PluginLoader : public PluginLoaderBase {
+  class PluginLoader : public PluginLoaderBase {
   protected:
     PluginLoader() : PluginLoaderBase() {}
 
@@ -106,7 +107,7 @@ namespace KPIM {
         pointer if the type wasn't found. You can extend this method
         for when you want to handle builtin types */
     virtual T * createForName( const QString & type ) const {
-      void * main_func = mainFunc( type, T_config::mainfunc );
+      KLibrary::void_function_ptr main_func = mainFunc( type, T_config::mainfunc );
       if ( !main_func ) return 0;
 
       // cast to a pointer to a function returning T*, call it and
