@@ -1,5 +1,7 @@
 // binhex.cpp
 
+#define DW_IMPLEMENTATION
+
 #include <string.h>
 #include <mimelib/binhex.h>
 
@@ -418,13 +420,13 @@ DwBinhex::DwBinhex()
 {
     Initialize();
 }
-
+#endif // 0
 
 DwBinhex::~DwBinhex()
 {
 }
 
-
+#if 0
 void DwBinhex::Initialize()
 {
     memset(mFileName, 0, sizeof(mFileName));
