@@ -45,13 +45,12 @@
 #include <kcal/incidence.h>
 #include <kcal/incidenceformatter.h>
 
-#include <kpimprefs.h> // for the time zone
-
 #include <kmail/callback.h>
 
 #include <kpimutils/email.h>
 
 #include <kglobal.h>
+#include <kfiledialog.h>
 #include <kinputdialog.h>
 #include <klocale.h>
 #include <kstringhandler.h>
@@ -61,15 +60,19 @@
 #include <kdbusservicestarter.h>
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
-#include <kapplication.h>
+#include <ksystemtimezone.h>
 #include <ktemporaryfile.h>
+#include <kmimetype.h>
+#include <kmenu.h>
+#include <krun.h>
+#include <ktoolinvocation.h>
+#include <kio/netaccess.h>
 
 #include <QUrl>
 #include <QDir>
 #include <QTextStream>
 
 #include <kdemacros.h>
-#include <coreinterface.h>
 #include "calendarinterface.h"
 
 using namespace KCal;
@@ -89,7 +92,7 @@ class CalendarManager
 
 CalendarManager::CalendarManager()
 {
-  mCalendar = new CalendarResources( KPIM::KPimPrefs::timeSpec() );
+  mCalendar = new CalendarResources( KSystemTimeZones::local() );
   mCalendar->readConfig();
   mCalendar->load();
   bool multipleKolabResources = false;
@@ -146,7 +149,7 @@ class Formatter : public KMail::Interface::BodyPartFormatter
       if ( !writer )
         // Guard against crashes in createReply()
         return Ok;
-      CalendarLocal cl( KPIM::KPimPrefs::timeSpec() );
+      CalendarLocal cl( KSystemTimeZones::local() );
       KMInvitationFormatterHelper helper( bodyPart );
       QString source;
       /* If the bodypart does not have a charset specified, we need to fall
@@ -167,6 +170,18 @@ class Formatter : public KMail::Interface::BodyPartFormatter
     }
 };
 
+static Incidence *icalToString( const QString& iCal )
+{
+  CalendarLocal calendar( KSystemTimeZones::local() ) ;
+  ICalFormat format;
+  ScheduleMessage *message =
+    format.parseScheduleMessage( &calendar, iCal );
+  if ( !message )
+    //TODO: Error message?
+    return 0;
+  return dynamic_cast<Incidence*>( message->event() );
+}
+
 class UrlHandler : public KMail::Interface::BodyPartURLHandler
 {
   public:
@@ -175,19 +190,6 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
       kDebug() <<"UrlHandler() (iCalendar)";
     }
 
-    Incidence* icalToString( const QString& iCal ) const
-    {
-      CalendarLocal calendar( KPIM::KPimPrefs::timeSpec() ) ;
-      ICalFormat format;
-      ScheduleMessage *message =
-        format.parseScheduleMessage( &calendar, iCal );
-      if ( !message )
-        //TODO: Error message?
-        return 0;
-      return dynamic_cast<Incidence*>( message->event() );
-    }
-
-
     Attendee *findMyself( Incidence* incidence, const QString& receiver ) const
     {
       Attendee::List attendees = incidence->attendees();
@@ -244,6 +246,45 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
 
     }
 
+    static Attachment *findAttachment( const QString &name, const QString &iCal )
+    {
+      Incidence *incidence = icalToString( iCal );
+
+      // get the attachment by name from the incidence
+      Attachment::List as = incidence->attachments();
+      Attachment *a = 0;
+      if ( as.count() > 0 ) {
+        Attachment::List::ConstIterator it;
+        for ( it = as.constBegin(); it != as.constEnd(); ++it ) {
+          if ( (*it)->label() == name ) {
+            a = *it;
+            break;
+          }
+        }
+      }
+
+      if ( !a ) {
+        KMessageBox::error(
+          0,
+          i18n("No attachment named \"%1\" found in the invitation.", name ) );
+        return 0;
+      }
+
+      if ( a->isUri() ) {
+        if ( !KIO::NetAccess::exists( a->uri(), KIO::NetAccess::SourceSide, 0 ) ) {
+          KMessageBox::information(
+            0,
+            i18n( "The invitation attachment \"%1\" is a web link that "
+                  "is inaccessible from this computer. Please ask the event "
+                  "organizer to resend the invitation with this attachment "
+                  "stored inline instead of a link.",
+                  KUrl::fromPercentEncoding( a->uri().toLatin1() ) ) );
+          return 0;
+        }
+      }
+      return a;
+    }
+
     Attendee* setStatusOnMyself( Incidence* incidence, Attendee* myself,
                             Attendee::PartStat status, const QString &receiver ) const
     {
@@ -285,7 +326,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
     {
       //status is accepted/tentative/declined
       ICalFormat format;
-      format.setTimeSpec( KPIM::KPimPrefs::timeSpec() );
+      format.setTimeSpec( KSystemTimeZones::local() );
       QString msg = format.createScheduleMessage( incidence, method );
       QString summary = incidence->summary();
       if ( summary.isEmpty() )
@@ -387,7 +428,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
         if ( !ok )
           return true;
         if ( !comment.isEmpty() ) {
-          if ( callback.exchangeCompatibleInvitations() ) {
+          if ( callback.outlookCompatibleInvitationReplyComments() ) {
             incidence->setDescription( comment );
           } else {
             incidence->addComment( comment );
@@ -491,7 +532,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
         incidence->addAttendee( delegate );
 
         ICalFormat format;
-        format.setTimeSpec( KPIM::KPimPrefs::timeSpec() );
+        format.setTimeSpec( KSystemTimeZones::local() );
         QString iCal = format.createScheduleMessage( incidence, iTIPRequest );
         saveFile( receiver, iCal, dir );
 
@@ -500,6 +541,80 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
       return ok;
     }
 
+    bool openAttachment( const QString &name, const QString &iCal ) const
+    {
+      Attachment *a = findAttachment( name, iCal );
+      if ( !a ) {
+        return false;
+      }
+
+      if ( a->isUri() ) {
+        KToolInvocation::invokeBrowser( a->uri() );
+      } else {
+        // put the attachment in a temporary file and launch it
+        KTemporaryFile *file = new KTemporaryFile();
+        QStringList patterns = KMimeType::mimeType( a->mimeType() )->patterns();
+        if ( !patterns.empty() ) {
+          file->setSuffix( QString( patterns.first() ).remove( '*' ) );
+        }
+        file->open();
+        file->setPermissions( QFile::ReadUser );
+        file->write( QByteArray::fromBase64( a->data() ) );
+        file->close();
+
+        bool stat = KRun::runUrl( KUrl( file->fileName() ), a->mimeType(), 0, true );
+        delete file;
+        return stat;
+      }
+      return true;
+    }
+
+    bool saveAsAttachment( const QString &name, const QString &iCal ) const
+    {
+      Attachment *a = findAttachment( name, iCal );
+      if ( !a ) {
+        return false;
+      }
+
+      // get the saveas file name
+      QString saveAsFile =
+        KFileDialog::getSaveFileName( name,
+                                      QString(), 0,
+                                      i18n( "Save Invitation Attachment" ));
+
+      if ( saveAsFile.isEmpty() ||
+           ( QFile( saveAsFile ).exists() &&
+             ( KMessageBox::warningContinueCancel(
+               0,
+               i18nc( "@info",
+                      "File <filename>%1</filename> exists.<nl/> Do you want to replace it?",
+                      saveAsFile ) ) != KMessageBox::Continue ) ) ) {
+        return false;
+      }
+
+      bool stat = false;
+      if ( a->isUri() ) {
+        // save the attachment url
+        stat = KIO::NetAccess::file_copy( a->uri(), KUrl( saveAsFile ) );
+      } else {
+        // put the attachment in a temporary file and save it
+        KTemporaryFile *file = new KTemporaryFile();
+        QStringList patterns = KMimeType::mimeType( a->mimeType() )->patterns();
+        if ( !patterns.empty() ) {
+          file->setSuffix( QString( patterns.first() ).remove( '*' ) );
+        }
+        file->open();
+        file->setPermissions( QFile::ReadUser );
+        file->write( QByteArray::fromBase64( a->data() ) );
+        file->close();
+
+        stat = KIO::NetAccess::file_copy( KUrl( file->fileName() ), KUrl( saveAsFile ) );
+
+        delete file;
+      }
+      return stat;
+    }
+
     void showCalendar( const QDate &date ) const
     {
       ensureKorganizerRunning();
@@ -534,7 +649,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
         if ( !ok )
           return true;
         if ( !comment.isEmpty() ) {
-          if ( callback.exchangeCompatibleInvitations() ) {
+          if ( callback.outlookCompatibleInvitationReplyComments() ) {
             incidence->setDescription( comment );
           } else {
             incidence->addComment( comment );
@@ -633,16 +748,49 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
           result = true;
         }
       }
+      if ( path.startsWith( QLatin1String( "ATTACH:" ) ) ) {
+        QString name = path;
+        name.remove( QRegExp( "^ATTACH:" ) );
+        result = openAttachment( name, iCal );
+      }
+
       if ( result )
         c.closeIfSecondaryWindow();
       return result;
     }
 
-    bool handleContextMenuRequest( KMail::Interface::BodyPart *,
-                                   const QString &,
-                                   const QPoint & ) const
+    bool handleContextMenuRequest( KMail::Interface::BodyPart *part,
+                                   const QString &path,
+                                   const QPoint &point ) const
     {
-      return false;
+      QString name = path;
+      if ( path.startsWith( QLatin1String( "ATTACH:" ) ) ) {
+        name.remove( QRegExp( "^ATTACH:" ) );
+      } else {
+        return false; //because it isn't an attachment inviation
+      }
+
+      QString iCal;
+      if ( part->contentTypeParameter( "charset").isEmpty() ) {
+        const QByteArray &ba = part->asBinary();
+        iCal = QString::fromUtf8( ba );
+      } else {
+        iCal = part->asText();
+      }
+
+      KMenu *menu = new KMenu();
+      QAction *open =
+        menu->addAction( KIcon( "document-open" ), i18n( "Open Attachment" ) );
+      QAction *saveas =
+        menu->addAction( KIcon( "document-save-as" ), i18n( "Save Attachment As..." ) );
+
+      QAction *a = menu->exec( point, 0 );
+      if ( a == open ) {
+        openAttachment( name, iCal );
+      } else if ( a == saveas ) {
+        saveAsAttachment( name, iCal );
+      }
+      return true;
     }
 
     QString statusBarMessage( KMail::Interface::BodyPart *,
@@ -650,9 +798,9 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
     {
       if ( !path.isEmpty() ) {
         if ( path == "accept" )
-          return i18n("Accept incidence");
+          return i18n("Accept invitation");
         if ( path == "accept_conditionally" )
-          return i18n( "Accept incidence conditionally" );
+          return i18n( "Accept invitation conditionally" );
         if ( path == "accept_counter" )
           return i18n( "Accept counter proposal" );
         if ( path == "counter" )
@@ -660,19 +808,24 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
         if ( path == "ignore" )
           return i18n( "Throw mail away" );
         if ( path == "decline" )
-          return i18n( "Decline incidence" );
+          return i18n( "Decline invitation" );
         if ( path == "decline_counter" )
           return i18n( "Decline counter proposal" );
         if ( path == "check_calendar" )
           return i18n("Check my calendar..." );
         if ( path == "reply" )
-          return i18n( "Enter incidence into my calendar" );
+          return i18n( "Record response into my calendar" );
         if ( path == "delegate" )
-          return i18n( "Delegate incidence" );
+          return i18n( "Delegate invitation" );
         if ( path == "forward" )
-          return i18n( "Forward incidence" );
+          return i18n( "Forward invitation" );
         if ( path == "cancel" )
-          return i18n( "Remove incidence from my calendar" );
+          return i18n( "Remove invitation from my calendar" );
+        if ( path.startsWith( QLatin1String( "ATTACH:" ) ) ) {
+          QString name = path;
+          return i18n( "Open attachment \"%1\"",
+                       name.remove( QRegExp( "^ATTACH:" ) ) );
+        }
       }
 
       return QString();
